import type { MedipassRequestOpts, MfaUser, Account, CreateOrganisationSupportAccountBody } from '../types';
/**
 * Create account secret key
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const createAccountSecretKey: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create organisation account
 * @param {String} organisationId - Organisation ID
 * @param {Object} body - Response body
 * @param {Object} opts - Additional options
 */
export declare const createOrganisationAccount: (organisationId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create organisation support account
 * @param {String} organisationId - Organisation ID
 * @param {Object} body - Response body
 * @param {Object} opts - Additional options
 */
export declare const createOrganisationSupportAccount: (organisationId: string, body: CreateOrganisationSupportAccountBody, opts?: MedipassRequestOpts) => Promise<Account>;
/**
 * Delete account secret key
 * @param {String} accountId - Account ID
 * @param {String} secretKey - Secret Key
 * @param {Object} opts - Additional options
 */
export declare const deleteAccountSecretKey: (accountId: string, secretKey: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete account
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const deleteAccount: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Disable account
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const disableAccount: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Enable account
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const enableAccount: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Request reset for account # DEPRECATED
 * @param {String} email - Account email address
 * @param {String} accountType - Account type (business, consumer, healthfund)
 * @param {Object} opts - Additional options
 */
export declare const requestAccountReset: (email: string, accountType: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Request password reset for username-based Tyro Health accounts
 * @param {Object} opts - Account ID or email
 * @param {String} accountType - Account type (business, consumer, healthfund). Will fail for consumer account.
 * @param {Object} opts - Additional options
 */
export declare const requestPasswordReset: ({ accountId, email }: {
    accountId?: string | null | undefined;
    email?: string | null | undefined;
}, accountType: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Request mobile reset for mobile-based Tyro Health accounts
 * @param {Object} opts - Account ID or mobile
 * @param {String} accountType - Account type (business, consumer, healthfund). Will fail for non consumer accounts.
 * @param {Object} opts - Additional options
 */
export declare const requestMobileReset: ({ accountId, email }: {
    accountId?: string | null | undefined;
    email?: string | null | undefined;
}, accountType: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Reset an account # DEPRECATED
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const resetAccount: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Reset a password for username-based Tyro Health accounts
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const resetPassword: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Reset a mobile number for mobile-based Tyro Health accounts
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const resetMobile: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Verify an account
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const verifyAccount: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get accounts
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getAccounts: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund account
 * @param {String} healthFundId - The health fund ID
 * @param {String} accountId - The account ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundAccount: (healthFundId: string, accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund accounts
 * @param {String} healthFundId - The health fund ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundAccounts: (healthFundId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get organisation accounts
 * @param {String} organisationId - The organisation ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getOrganisationAccounts: (organisationId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get account
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const getAccount: (accountId: string, opts?: MedipassRequestOpts) => Promise<Account>;
/**
 * Get business staff account
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessStaffAccount: (businessId: string, staffId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Check if account exists
 * @param {String} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getAccountExists: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Returns the current account
 * @param {Object} opts - Additional options
 */
export declare const getCurrentAccount: (opts?: MedipassRequestOpts) => Promise<Account>;
/**
 * Get account roles
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const getAccountRoles: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get account secret keys
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const getAccountSecretKeys: (accountId: string, opts?: MedipassRequestOpts) => Promise<Array<Record<string, any>>>;
/**
 * Get account transactions
 * @param {String} accountId - Account ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getAccountTransactions: (accountId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Invite health fund account
 * @param {String} healthFundId - The health fund ID
 * @param {Object} requestBody - Request body
 * @param {Object} opts - Additional options
 */
export declare const inviteHealthFundAccount: (healthFundId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Remove health fund from account
 * @param {String} healthFundId - Health fund ID
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const removeHealthFundFromAccount: (healthFundId: string, accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Request to verify an account
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const requestToVerifyAccount: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Sign up for an account
 * @param {String} email - Account email address
 * @param {String} mobile - Mobile number
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const signUp: (email: string, mobile: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Accept an invite
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const acceptInvite: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update account
 * @param {String} accountId - Account ID
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const updateAccount: (accountId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update account roles
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const updateAccountRoles: (accountId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get account practices
 * @param {String} accountId - Account ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getAccountPractices: (accountId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Change password
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const changePassword: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Enable SMS MFA
 * @param {String} accountId - Account ID
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const enableTwoFactorAuthentication: (accountId: string, body: {
    otkCode?: string;
    password: string;
    mobile: string;
    countryCode: string;
}, opts?: MedipassRequestOpts) => Promise<MfaUser>;
/**
 * Disable SMS MFA
 * @param {String} accountId - Account ID
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const disableTwoFactorAuthentication: (accountId: string, body: {
    otkCode?: string;
    password: string;
}, opts?: MedipassRequestOpts) => Promise<MfaUser>;
/**
 * Update SMS MFA AUTH
 * @param {String} accountId - Account ID
 * @param {Object} body - Object body
 * @param {Object} opts - Additional options
 */
export declare const updateTwoFactorAuthentication: (accountId: string, body: {
    otkCode?: string;
    password: string;
    mobile: string;
    countryCode: string;
    oldOtkCode?: string;
}, opts?: MedipassRequestOpts) => Promise<MfaUser>;
