import type { MedipassRequestOpts, VirusScan } from '../types';
export declare const pathGetClaimAttachmentUrl: (businessId: string, practiceId: string, staffId: string) => string;
export declare const pathGetS3SignedUrl: (businessId: string, practiceId: string, staffId: string, s3SignedUrlId: string) => string;
export declare const pathScanClaimFile: (businessId: string, practiceId: string, staffId: string) => string;
export declare const pathScanFile: (businessId: string) => string;
export declare const pathGetAttachmentUrl: (businessId: string) => string;
export declare const pathGetBusinessS3SignedUrl: (businessId: string, s3SignedUrlId: string) => string;
/**
 * Get url to upload a file associated to a claim
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getClaimAttachmentUrl: (businessId: string, practiceId: string, staffId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Scan a file associated to a claim
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const scanClaimFile: (businessId: string, practiceId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get s3 signed url
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {String} s3SignedUrlId - Internal s3 signed url ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getS3SignedUrl: (businessId: string, practiceId: string, staffId: string, s3SignedUrlId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
export interface ScanFilePayload {
    s3SignedUrlId: string;
}
/**
 * Scan a file
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const scanFile: (businessId: string, body: ScanFilePayload, opts?: MedipassRequestOpts) => Promise<VirusScan>;
export interface GetAttachmentUrlQuery {
    businessId: string;
    contentType: string;
    healthFundId: string;
    contentLenth: number;
}
/**
 * Get url to upload a file
 * @param {String} businessId - Business ID
 * @param {Object} query - Query
 * @param {Object} opts - Additional options
 */
export declare const getAttachmentUrl: (businessId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
export declare type GetBusinessS3SignedUrlResponse = {
    _id: string;
    businessId: string;
    s3Bucket: string;
    s3Key: string;
    antiVirusStatus: string;
    antiVirusTimestamp: string;
    viruses: string[];
    created: string;
    modified: string;
};
/**
 * Get a business' s3 signed url
 * @param {String} businessId - Business ID
 * @param {String} s3SignedUrlId - Internal s3 signed url ID
 * @param {Object} query - Request query
 * @param {Object} opts - Additional options
 */
export declare const getBusinessS3SignedUrl: (businessId: string, s3SignedUrlId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<GetBusinessS3SignedUrlResponse>;
