import type { MedipassRequestOpts } from '../types';
export declare const PATH__AUTH = "/auth";
export declare const PATH__OTK = "/otk";
export declare const PATH__AUTH_TOKEN = "/auth/token";
export declare const pathImpersonateAccount: (accountId: any) => string;
export declare const pathAuthy: (accountId: string) => string;
export declare const pathAuthyVerify: (accountId: string) => string;
export declare const HEADER__SUPER_ADMIN = "x-super-admin";
export declare const HEADER__READ_ONLY_ADMIN = "x-read-only-admin";
/**
 * Log in a user
 * @param {String} email - Email
 * @param {String} password - Password
 * @param {{ otkCode: ?String, accountType: String }} body - The request body
 * @param {{ ver: ?String }} opts - Additional options
 */
export declare const login: (email?: string | null | undefined, password?: string | null | undefined, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Login with token
 * @param {String} accountId - Account ID
 * @param {String} token - JWT
 */
export declare const loginWithToken: (token: string, accountId: string) => Promise<Record<string, any>>;
/**
 * Impersonate a user
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const impersonate: (accountId: string, opts?: MedipassRequestOpts) => Promise<any>;
/**
 * Log out a user
 * @param {Object} opts - Additional options
 */
export declare const logout: (opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Object OTK
 * @param {String} email - Email address
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const requestOtk: (email?: string | null | undefined, accountId?: string | null | undefined, requestBody?: Record<string, any> | null | undefined, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Generate Authy
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const generateAuthy: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Remove Authy
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const removeAuthy: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Verify Authy
 * @param {String} accountId - Account ID
 * @param {String} token - Authy Token
 * @param {Object} opts - Additional options
 */
export declare const verifyAuthy: (accountId: string, token: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a short lived token
 * @param {String} apiKey - API Key
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createShortLivedToken: (apiKey: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<any>;
