import type { MedipassRequestOpts, Business, TerminalPin } from '../types';
/**
 * Create businesses
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusiness: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create organisation businesses
 * @param {String} organisationId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createOrganisationBusiness: (organisationId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete business
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const deleteBusiness: (businessId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Disable business
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const disableBusiness: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Email business setup questions to support
 * @param {Object} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const emailBusinessOnboardingQuestions: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Enable business
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const enableBusiness: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusiness: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business billing history
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessBillingHistoryRecords: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a single business billing record
 * @param {String} businessId - Business ID
 * @param {String} billingHistoryId - Billing ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessBillingHistoryRecord: (businessId: string, billingHistoryId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get businesses
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinesses: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get businesses
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getMyBusinesses: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business PDFs
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPDFs: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get accounts businesses
 * @param {String} accountId - Organisation ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getAccountsBusinesses: (accountId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get organisation businesses
 * @param {String} organisationId - Organisation ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getOrganisationBusinesses: (organisationId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update businesses
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateBusiness: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Unsuspend business
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const unsuspendBusiness: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Business>;
export interface MedicareVerificationResponse {
    correlationId: string;
    patientVerified: boolean;
    concessionVerified?: boolean;
    isUpdateRequired: boolean;
    isNotificationRequired: boolean;
    healthFundAccount: Record<string, any>;
    patient: {
        code: number;
        message: string;
        responded?: string;
    };
    concession: {
        code: number;
        message: string;
        responded?: string;
    };
}
/**
 * Verify Medicare
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyMedicare: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<MedicareVerificationResponse>;
/**
 * Old verify DVA - This can be removed once we migrate to the new medicare service
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const oldVerifyDVA: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
export interface DvaVerificationResponse {
    correlationId: string;
    patientVerified: boolean;
    isUpdateRequired: boolean;
    isNotificationRequired: boolean;
    healthFundAccount: Record<string, any>;
    patient: {
        code: number;
        message: string;
        responded?: string;
    };
}
/**
 * Verify DVA
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyDVA: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<DvaVerificationResponse>;
/**
 * Verify icare
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyIcare: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Verify Comcare claim number
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} providerSetItemId - Provider set item ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyComcare: (businessId: string, staffId: string, providerSetItemId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create business support note
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createSupportNote: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get bank state branch (BSB) details
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getBsbDetails: (businessId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send email to business
 * @param {Object} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const sendBusinessEmail: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Suspend business
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const suspendBusiness: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Business>;
export interface GetOrgByHealthFundExistsQuery {
    healthFundId: string;
}
/**
 * Search if the business exists for a healthfund
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const getOrgByHealthFundExists: (businessId: string, query: GetOrgByHealthFundExistsQuery, opts?: MedipassRequestOpts) => Promise<Business>;
/**
 * Suspend business email
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const suspendBusinessEmail: (businessId: string, opts?: MedipassRequestOpts) => Promise<Business>;
/**
 * Get a current terminal 6 digit pin for terminal authentication
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessTerminalPin: (businessId: string, opts?: MedipassRequestOpts) => Promise<TerminalPin>;
/**
 * Create a 6 digit pin for a terminal authentication
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const createBusinessTerminalPin: (businessId: string, opts?: MedipassRequestOpts) => Promise<TerminalPin>;
