import type { BusinessDocumentsQuery, BusinessDocumentResponse, BusinessDocumentsResponse, CeaseHealthFundDocumentBody, DeclineHealthFundDocumentBody, HealthFundDocumentResponse, HealthFundDocumentsResponse, HealthFundDocumentsQuery, ParkHealthFundDocumentBody, MedipassRequestOpts, HealthPointRegistrationApplicationResponse, ActivateHealthPointDigitalClaimingBody, UpdateHealthPointRegistrationApplicationBody } from '../types';
export declare const pathBusinessDocuments: (businessId: string) => string;
export declare const pathBusinessDocument: (businessId: string, documentId: string) => string;
export declare const pathBusinessDocumentCancel: (businessId: string, documentId: string) => string;
export declare const pathHealthFundDocument: (healthFundId: string, documentId: string) => string;
export declare const pathHealthFundDocumentApprove: (healthFundId: string, documentId: string) => string;
export declare const pathHealthFundDocumentAssignToMe: (healthFundId: string, documentId: string) => string;
export declare const pathHealthFundDocumentDecline: (healthFundId: string, documentId: string) => string;
export declare const pathHealthFundDocumentCease: (healthFundId: string, documentId: string) => string;
export declare const pathHealthFundDocumentPark: (healthFundId: string, documentId: string) => string;
export declare const pathHealthFundDocumentTag: (healthFundId: string, documentId: string, tagId: string) => string;
export declare const pathHealthFundDocuments: (healthFundId: string) => string;
export declare const pathHealthFundHealthPointRegistrationApplication: (healthFundId: string, healthPointRegistrationApplicationId: string) => string;
export declare const pathHealthFundHealthPointActivateDigitalClaiming: (healthFundId: string, healthPointRegistrationApplicationId: string) => string;
/**
 * Approve health fund document
 * @param {String} healthFundId - Business ID
 * @param {String} documentId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const approveHealthFundDocument: (healthFundId: string, documentId: string, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentResponse>;
/**
 * Get business documents
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const assignHealthFundDocumentToMe: (healthFundId: string, documentId: string, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentResponse>;
/**
 * Cancel business document
 * @param {String} businessId - Business ID
 * @param {String} documentId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const cancelBusinessDocument: (businessId: string, documentId: string, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentResponse>;
/**
 * Decline health fund document
 * @param {String} healthFundId - Business ID
 * @param {String} documentId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const declineHealthFundDocument: (healthFundId: string, documentId: string, body: DeclineHealthFundDocumentBody, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentResponse>;
/**
 * Cease health fund document
 * @param {String} healthFundId - Business ID
 * @param {String} documentId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const ceaseHealthFundDocument: (healthFundId: string, documentId: string, body: CeaseHealthFundDocumentBody, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentResponse>;
/**
 * Delete business document tag
 * @param {String} businessId - Business ID
 * @param {String} documentId - Document ID
 * @param {String} tagId - Tag ID
 * @param {Object} opts - Additional options
 */
export declare const deleteHealthFundDocumentTag: (healthFundId: string, documentId: string, tagId: string, opts?: MedipassRequestOpts) => Promise<null>;
/**
 * Get business documents
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessDocuments: (businessId: string, query?: BusinessDocumentsQuery, opts?: MedipassRequestOpts) => Promise<BusinessDocumentsResponse>;
/**
 * Get business document
 * @param {String} businessId - Business ID
 * @param {String} documentId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessDocument: (businessId: string, documentId: string, opts?: MedipassRequestOpts) => Promise<BusinessDocumentResponse>;
/**
 * Get health fund documents
 * @param {String} healthFundId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundDocuments: (healthFundId: string, query: HealthFundDocumentsQuery, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentsResponse>;
/**
 * Get health fund document
 * @param {String} healthFundId - Business ID
 * @param {String} documentId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundDocument: (healthFundId: string, documentId: string, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentResponse>;
/**
 * Park a health fund document
 * @param {String} healthFundId - Business ID
 * @param {String} documentId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const parkHealthFundDocument: (healthFundId: string, documentId: string, body: ParkHealthFundDocumentBody, opts?: MedipassRequestOpts) => Promise<HealthFundDocumentResponse>;
/**
 * Get HealthPoint Registration Applications
 * @param {String} healthFundId - Business ID
 * @param {String} healthPointRegistrationApplicationId - Document ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthPointRegistrationApplication: (healthFundId: string, healthPointRegistrationApplicationId: string, opts?: MedipassRequestOpts) => Promise<HealthPointRegistrationApplicationResponse>;
/**
 * Update HealthPoint Registration Application
 * @param {String} healthFundId - Business ID
 * @param {String} healthPointRegistrationApplicationId - Document ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateHealthPointRegistrationApplication: (healthFundId: string, healthPointRegistrationApplicationId: string, body: UpdateHealthPointRegistrationApplicationBody, opts?: MedipassRequestOpts) => Promise<HealthPointRegistrationApplicationResponse>;
/**
 * Activate HealthPoint Digital Claiming
 * @param {String} healthFundId - Business ID
 * @param {String} healthPointRegistrationApplicationId - Document ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const activateHealthPointDigitalClaiming: (healthFundId: string, healthPointRegistrationApplicationId: string, body: ActivateHealthPointDigitalClaimingBody, opts?: MedipassRequestOpts) => Promise<HealthPointRegistrationApplicationResponse>;
