import type { ApplyForBusinessFormRequestBody, CreateHealthFundFormRequestBody, GetHealthFundFormsQuery, GetHealthFundFormUploadUrlQuery, MedipassRequestOpts, UpdateHealthFundFormRequestBody } from '../types';
export declare const pathBusinessForm: (businessId: string, formId: string) => string;
export declare const pathBusinessFormApplications: (businessId: string, formId: string) => string;
export declare const pathHealthFundForm: (healthFundId: string, formId: string) => string;
export declare const pathHealthFundFormPublish: (healthFundId: string, formId: string) => string;
export declare const pathHealthFundFormUnpublish: (healthFundId: string, formId: string) => string;
export declare const pathHealthFundForms: (healthFundId: string) => string;
export declare const pathHealthFundFormUploadUrl: (healthFundId: string) => string;
export declare const pathGetLatestApprovedDocument: (businessId: string, practiceId: string, formId: string) => string;
export declare const pathGetManualFormUploadUrl: (businessId: string, practiceId: string, formId: string) => string;
/**
 * Apply for a business form
 * @param {String} healthFundId - Health fund ID
 * @param {String} formId - Form ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const applyForBusinessForm: (businessId: string, formId: string, body: ApplyForBusinessFormRequestBody, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create health fund form
 * @param {String} healthFundId - Health fund ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createHealthFundForm: (healthFundId: string, body: CreateHealthFundFormRequestBody, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete health fund form
 * @param {String} healthFundId - Health fund ID
 * @param {String} formId - Form ID
 * @param {Object} opts - Additional options
 */
export declare const deleteHealthFundForm: (healthFundId: string, formId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business form
 * @param {String} businessId - Business ID
 * @param {String} formId - Form ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessForm: (businessId: string, formId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund forms
 * @param {String} healthFundId - Health fund ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundForms: (healthFundId: string, query?: GetHealthFundFormsQuery, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund form
 * @param {String} healthFundId - Health fund ID
 * @param {String} formId - Form ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundForm: (healthFundId: string, formId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund form
 * @param {String} healthFundId - Health fund ID
 * @param {String} formId - Form ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundFormUploadUrl: (healthFundId: string, query: GetHealthFundFormUploadUrlQuery, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Publish a health fund form
 * @param {String} healthFundId - Health fund ID
 * @param {String} formId - Form ID
 * @param {Object} opts - Additional options
 */
export declare const publishHealthFundForm: (healthFundId: string, formId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update health fund form
 * @param {String} healthFundId - Health fund ID
 * @param {String} formId - Form ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateHealthFundForm: (healthFundId: string, formId: string, body: UpdateHealthFundFormRequestBody, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Unpublish a health fund form
 * @param {String} healthFundId - Health fund ID
 * @param {String} formId - Form ID
 * @param {Object} opts - Additional options
 */
export declare const unpublishHealthFundForm: (healthFundId: string, formId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get latest approved document
 * @param {String} businessId - business ID
 * @param {String} practiceId - practice ID
 * @param {String} formId - Form ID
 * @param {Object} opts - Additional options
 */
export declare const getLatestApprovedDocument: (businessId: string, practiceId: string, formId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get url to upload a file associated to a manual form
 * @param {String} businessId - business ID
 * @param {String} practiceId - practice ID
 * @param {String} formId - Form ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getManualFormUploadUrl: (businessId: string, practiceId: string, formId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
