import type { MedipassRequestOpts } from '../types';
export declare const pathBusinessFutures: (businessId: string) => string;
export declare const pathBusinessFuture: (businessId: string, futureId: string) => string;
export declare const pathBusinessHolds: (businessId: string) => string;
export declare const pathBusinessInstalmentPlans: (businessId: string) => string;
export declare const pathFuture: (futureId: string) => string;
export declare const pathProcessingRequests: (futureId: string) => string;
export declare const pathPaymentLink: (futureId: string) => string;
export declare const pathCancels: (futureId: string) => string;
export declare const pathSubmits: (futureId: string) => string;
export declare const pathSendReceipt: (futureId: string) => string;
/**
 * Create business hold
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessHold: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create business instalment plan
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessInstalmentPlan: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Cancel a future
 * @param {String} futureId - Future ID
 * @param {Object} opts - Additional options
 */
export declare const cancel: (futureId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business futures
 * @param {String} businessId - Business ID
 * @param {Object} query - Request query
 * @param {Object} opts - Additional options
 */
export declare const getBusinessFutures: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business future
 * @param {String} businessId - Business ID
 * @param {String} futureId - Future ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessFuture: (businessId: string, futureId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a future
 * @param {String} futureId - Future ID
 * @param {Object} opts - Additional options
 */
export declare const getFuture: (futureId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get payment link
 * @param {String} futureId - Future ID
 * @param {Object} opts - Additional options
 */
export declare const getPaymentLink: (futureId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send processing request
 * @param {String} futureId - Future ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const sendProcessingRequest: (futureId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Submit a future
 * @param {String} futureId - Future ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const submit: (futureId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update a future
 * @param {String} futureId - Future ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const update: (futureId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send a payment receipt for a future
 * @param {String} futureId - Future ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const sendReceipt: (futureId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
