import type { MedipassRequestOpts } from '../types';
/**
 * Create a member's health fund account
 * @param {String} memberId - Member ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createMembersHealthFundAccount: (memberId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a business patient health fund account
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessPatientHealthFundAccount: (businessId: string, patientId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete a member's health fund account
 * @param {String} memberId - Member ID
 * @param {String} healthFundAccountId - healthFundAccountId
 * @param {Object} opts - Additional options
 */
export declare const deleteMembersHealthFundAccount: (memberId: string, healthFundAccountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete a business patient's health fund account
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {String} healthFundAccountId - healthFundAccountId
 * @param {Object} opts - Additional options
 */
export declare const deleteBusinessPatientHealthFundAccount: (businessId: string, patientId: string, healthFundAccountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a member's health fund accounts
 * @param {String} memberId - Member ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getMembersHealthFundAccounts: (memberId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a business patient's health fund accounts
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPatientHealthFundAccounts: (businessId: string, patientId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a member's health fund account
 * @param {String} memberId - Member ID
 * @param {String} healthFundAccount - Health fund account ID
 * @param {Object} opts - Additional options
 */
export declare const getMembersHealthFundAccount: (memberId: string, healthFundAccountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a business patient's health fund account
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {String} healthFundAccount - Health fund account ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPatientHealthFundAccount: (businessId: string, patientId: string, healthFundAccountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update a member's health fund account
 * @param {String} memberId - Member ID
 * @param {String} healthFundAccountId - healthFundAccountId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateMembersHealthFundAccounts: (memberId: string, healthFundAccountId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update a business patients's health fund account
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {String} healthFundAccountId - healthFundAccountId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateBusinessPatientHealthFundAccount: (businessId: string, patientId: string, healthFundAccountId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
