import type { MedipassRequestOpts } from '../types';
/**
 * Get health funds for account
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundsForAccount: (opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health funds for business
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessHealthFunds: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health funds
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getHealthFunds: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Array<Record<string, any>>>;
/**
 * Get health funds by organisation
 * @param {String} organisationId - Organisation ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getOrganisationHealthFunds: (organisationId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create health fund
 *
 * @param {Object} body - Health fund details
 * @param {Object} opts - Additional options
 */
export declare const createHealthFund: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund
 * @param {String} healthFundId - Health fund ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthFund: (healthFundId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update health fund
 * @param {Object} healthFundId - Health fund ID
 * @param {Object} body - Health fund details
 * @param {Object} opts - Additional options
 */
export declare const updateHealthFund: (healthFundId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete health fund
 * @param {Object} healthFundId - Health fund ID
 * @param {Object} opts - Additional options
 */
export declare const deleteHealthFund: (healthFundId: string, opts?: MedipassRequestOpts) => Promise<boolean>;
/**
 * Get Medicare health fund
 * @param {Object} opts - Additional options
 */
export declare const getMedicareHealthFund: (opts?: MedipassRequestOpts) => Promise<Record<string, any> | null | undefined>;
/**
 * Verify member by health fund
 * @param {String} healthFundId - Health fund ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyMember: (healthFundId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
