import type { MedipassRequestOpts, BusinessKycPinResponse, Kyc, UpdateBusinessKycBody } from '../types';
export declare const pathBusinessKyc: (businessId: string) => string;
export declare const pathPracticeKyc: (businessId: string, practiceId: string) => string;
export declare const pathBusinessCbo: (businessId: string) => string;
export declare const pathBusinessKycVerify: (businessId: string) => string;
export declare const pathBusinessKycUnverify: (businessId: string) => string;
export declare const pathPracticeKycVerify: (businessId: string, practiceId: string) => string;
export declare const pathPracticeKycUnverify: (businessId: string, practiceId: string) => string;
export declare const pathBusinessVerifyBeneficialOwner: (businessId: string) => string;
export declare const pathRequestVerificationSupport: (businessId: string) => string;
export declare const pathBusinessAddBeneficialOwner: (businessId: string) => string;
export declare const pathBusinessRemoveBeneficialOwner: (businessId: string, beneficialOwnerId: string) => string;
export declare const pathResumeComplexVerification: (businessId: string) => string;
export declare const pathGetTrustDocumentUploadUrl: (businessId: string) => string;
export declare const pathBusinessKycPin: (businessId: string) => string;
/**
 * Get business kyc
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessKyc: (businessId: string, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Get practice kyc
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const getPracticeKyc: (businessId: string, practiceId: string, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Update business kyc
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateBusinessKyc: (businessId: string, body: UpdateBusinessKycBody, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business cbo
 * @param {String} businessId - Business ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessCbo: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Verify business kyc
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const verifyBusinessKyc: (businessId: string, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Verify practice kyc
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const verifyPracticeKyc: (businessId: string, practiceId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Unverify business kyc
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const unverifyBusinessKyc: (businessId: string, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Unverify practice kyc
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const unverifyPracticeKyc: (businessId: string, practiceId: string, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Verify business beneficial owner
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyBusinessBeneficialOwner: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Kyc>;
/**
 * Send support email for help on Tyro Health's KYC process
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const requestVerificationSupport: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Add beneficial owner to a business
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const addBeneficialOwner: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Remove beneficial owner to a business
 * @param {String} businessId - Business ID
 * @param {String} beneficialOwnerId - Beneficial Owner ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const removeBeneficialOwner: (businessId: string, beneficialOwnerId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Enable Connect user to resume a complex KYC process
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const resumeComplexVerification: (businessId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get url to upload a trust document associated to a kyc
 * @param {String} businessId - business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getTrustDocumentUploadUrl: (businessId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business kyc pin
 * @param {String} businessId - Business ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessKycPin: (businessId: string, opts?: MedipassRequestOpts) => Promise<BusinessKycPinResponse>;
