import type { MedipassRequestOpts } from '../types';
/**
 * Check for duplicate member
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const checkDupe: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create member for an account
 * @param {string} accountId - Account ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createAccountMember: (accountId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete a members
 * @param {Object} memberId - Member ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const deleteMember: (memberId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Discover a member
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const discoverMember: (query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Invite someone to become a Tyro Health member
 * @param {String} businessId - Member ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const inviteAnyone: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send an SMS to member with link to download app
 * @param {String} memberId - Member ID
 * @param {Object} opts - Additional options
 */
export declare const inviteMember: (memberId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get members for an account
 * @param {string} accountId - Account ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getAccountMembers: (accountId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get members by health fund
 * @param {String} healthFundId - Health fund ID
 * @param {Object} opts - Additional options
 */
export declare const getMembersForHealthFund: (healthFundId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund member by member ID.
 * @param {String} healthFundId - Health Fund ID
 * @param {String} memberId - Member ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundMemberByMemberId: (healthFundId: string, memberId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business members
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessMembers: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business member
 * @param {String} businessId - Business ID
 * @param {String} memberId - Member ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessMember: (businessId: string, memberId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get members
 * @param {Object} opts - Additional options
 */
export declare const getMembers: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get member
 * @param {String} memberId - Member ID
 * @param {Object} opts - Additional options
 */
export declare const getMember: (memberId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update a members
 * @param {Object} memberId - Member ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateMember: (memberId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
