import type { MedipassRequestOpts } from '../types';
export declare const pathPracticeOnboardingApplications: (practiceId: string) => string;
export declare const pathBusinessPracticeOnboardingApplications: (businessId: string, practiceId: string) => string;
export declare const pathBusinessOnboardingApplications: (businessId: string) => string;
export declare const pathProviderSetItemOnboardingApplications: (businessId: string, staffId: string, providerSetItemId: string) => string;
export declare const pathProviderSetItemOnboardingApplication: (businessId: string, staffId: string, providerSetItemId: string) => string;
/**
 * Get submitPracticeOnboardingApplication
 * @param {string} practiceId - Practice ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const submitPracticeOnboardingApplication: (practiceId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a list of practice's onboarding applications
 * @param {String} businessId - Business ID
 * @param {string} practiceId - Practice ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeOnboardingApplications: (businessId: string, practiceId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get onboarding applications for business
 * @param {string} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessOnboardingApplications: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create onboarding application for business
 * @param {String} businessId - Business ID
 */
export declare const createBusinessOnboardingApplication: (businessId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update onboarding application for business
 * @param {String} businessId - Business ID
 */
export declare const updateBusinessOnboardingApplication: (businessId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create onboarding application for provider set item
 * @param {String} businessId - Business ID
 * @param {String} staffID - Staff ID
 * @param {String} providerSetItemId - Provider set item ID
 */
export declare const createProviderSetItemOnboardingApplication: (businessId: string, staffId: string, providerSetItemId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get onboarding applications for provider set item
 * @param {string} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getProviderSetItemOnboardingApplication: (businessId: string, staffId: string, providerSetItemId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
