import type { MedipassRequestOpts } from '../types';
export declare const pathOnboardingRequest: (onboardingRequestId: string) => string;
export declare const pathBusinessOnboardingRequests: (businessId: string) => string;
export declare const pathOnboardingRequestSubmit: (onboardingRequestId: string) => string;
export declare const pathOnboardingRequestOnboardingStep: (onboardingRequestId: string, onboardingStepId: string) => string;
/**
 * Get a onboarding request by Id
 * @param {String} onboardingRequestId - Onboarding Request Id
 * @param {Object} opts - Additional options
 */
export declare const getOnboardingRequest: (onboardingRequestId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a list of business' onboarding requests
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessOnboardingRequests: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create onboarding request
 * @param {String} businessId - Business ID
 */
export declare const createBusinessOnboardingRequest: (businessId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Submit onboarding request
 * @param {String} onboardingRequestId - Onboarding Request Id
 */
export declare const submitOnboardingRequest: (onboardingRequestId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update onboarding request step
 * @param {String} onboardingRequestId - Onboarding Request Id
 * @param {String} onboardingStepId - Onboarding Step Id
 */
export declare const updateOnboardingRequestStep: (onboardingRequestId: string, onboardingStepId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete onboarding request
 * @param {String} onboardingRequestId - Onboarding Request Id
 */
export declare const deleteOnboardingRequest: (onboardingRequestId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
