import type { MedipassRequestOpts } from '../types';
/**
 * Get partners
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getPartners: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get partner
 * @param {String} partnerId - Partner ID
 * @param {Object} opts - Additional options
 */
export declare const getPartner: (partnerId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update partner
 * @param {String} partnerId - Partner ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updatePartner: (partnerId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update partner practice
 * @param {String} partnerId - Partner ID
 * @param {String} fullNameId - Practice full name
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updatePartnerPractice: (partnerId: string, fullNameId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update partner practice provider data
 * @param {String} partnerId - Partner ID
 * @param {String} practiceId - Practice ID
 * @param {String} providerNumberId - Provider number
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updatePartnerPracticeProviderData: (partnerId: string, practiceId: string, providerNumberId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Verify partner account
 * @param {String} accountId - AccountId ID
 * @param {Boolean} forceVerification - Force verification
 * @param {Object} opts - Additional options
 */
export declare const verifyPartnerAccount: (accountId: string, forceVerification?: boolean, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Notify partner account
 * @param {String} accountId - AccountId ID
 * @param {Object} opts - Additional options
 */
export declare const notifyPartnerAccount: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
