import type { MedipassRequestOpts } from '../types';
/**
 * Update patient payment information by SMS or Link
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const requestUpdatePatientPaymentMethod: (businessId: string, patientId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a business patient
 * @param {String} businessId - Business ID
 * @param {Object} body - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const createBusinessPatient: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business patients
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPatients: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a business patient
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPatient: (businessId: string, patientId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a business patient by ref id
 * @param {String} businessId - Business ID
 * @param {String} refId - Ref ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPatientByRefId: (businessId: string, refId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update a business patient
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {Object} body - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const updateBusinessPatient: (businessId: string, patientId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete a business patient
 * @param {String} businessId - Business ID
 * @param {String} patientId - Patient ID
 * @param {Object} opts - Additional options
 */
export declare const deleteBusinessPatient: (businessId: string, patientId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
