import type { MedipassRequestOpts } from '../types';
/**
 * Create business practice
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessPractice: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create organisation practice
 * @param {String} organisationId - Organisation ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createOrganisationPractice: (organisationId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete business practice
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const deleteBusinessPractice: (businessId: string, practiceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete organisation practice
 * @param {String} organisationId - Organisation ID
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const deleteOrganisationPractice: (organisationId: string, practiceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPractice: (businessId: string, practiceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practices
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPractices: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business form practices
 * @param {String} businessId - Business ID
 * @param {String} formId - Form ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessFormPractices: (businessId: string, formId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice upload urls
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} contentType - Mime type
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeUploadUrl: (businessId: string, practiceId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business staff practices
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessStaffPractices: (businessId: string, staffId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get organisation practices
 * @param {String} organisationId - Organisation ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getOrganisationPractices: (organisationId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get practice
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const getPractice: (practiceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Request to claim a practice
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const requestClaimPractice: (practiceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Request to add provider to practice
 * @param {String} practiceId - Practice ID
 * @param {String} providerNumber - Provider number
 * @param {Object} opts - Additional options
 */
export declare const requestToAddProviderToPractice: (practiceId: string, providerNumber: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Search practices for onboarding
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const searchOnboardingPractices: (query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update business practice
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateBusinessPractice: (businessId: string, practiceId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update organisation practice
 * @param {String} organisationId - Organisation ID
 * @param {String} practiceId - Practice ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateOrganisationPractice: (organisationId: string, practiceId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Verify a claim to a practice
 * @param {String} practiceId - Practice ID
 * @param {String} otkCode - One time token
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyClaimPractice: (practiceId: string, otkCode: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Clone practice into another business
 * @param {String} practiceId - Practice ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const clonePracticeIntoBusiness: (practiceId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get practices with approved applications
 * @param {String} businessId - business ID
 * @param {String} formId - Form ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getPracticesWithApprovedApplications: (businessId: string, formId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
