import type { MedipassRequestOpts } from '../types';
/**
 * Create a self checkout session
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createSelfCheckoutSession: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Approve my self checkout session
 * @param {Object} body - request body
 * @param {Object} opts - Additional options
 */
export declare const approve: (body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Cancel my self checkout session
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const cancel: (body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Cancel my self checkout session
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const cancelSession: (body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create invoice for my self checkout session
 * @param {Object} opts - Additional options
 */
export declare const createMyInvoice: (opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create payment authority for my self checkout session
 * @param {Object} opts - Additional options
 */
export declare const createPaymentAuthority: (opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create payment method for my self checkout session
 * @param {String} nonce - Nonce
 * @param {String} source - Source of payment
 * @param {Object} opts - Additional options
 */
export declare const createPaymentMethod: (nonce: string, source: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get payment methods for my self checkout session
 * @param {Object} opts - Additional options
 */
export declare const getPaymentMethods: (opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Discover member for a self checkout session
 * @param {Object} ids - Find by ids (Accepts: `memberId` and `email`)
 * @param {Object} query - Additional query parameters
 * @param {Object} opts - Additional options
 * @returns {Object} The device data
 */
export declare const discoverMember: ({ email, memberId }: {
    email?: string | undefined;
    memberId?: string | undefined;
}, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Check for duplicate member
 * @param {Object} body - Additional request body
 * @param {Object} opts - Additional options
 * @returns {Object} The device data
 */
export declare const checkDupe: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get my self checkout session
 * @param {Object} opts - Additional options
 */
export declare const getMySelfCheckoutSession: (opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction for self checkout session
 * @param {Object} opts - Additional options
 */
export declare const getMySelfCheckoutSessionTransaction: (checkoutSessionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Remember me
 * @param {Object} opts - Additional options
 */
export declare const rememberMe: (opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update my self checkout session
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateMySelfCheckoutSession: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Request OTK for a self checkout session
 * @param {String} accountId - Account ID
 * @param {Object} opts - Additional options
 */
export declare const requestOtk: (accountId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Add a payment method to a self checkout session
 * @param {Object} body - Config for the method.
 * @param {Object} opts - Additional options
 */
export declare const addPaymentMethodToSelfCheckoutSession: (body: {
    data?: Record<string, any>;
    selfCheckoutSession: Record<string, any>;
}, opts?: MedipassRequestOpts) => Promise<{
    paymentMethod: any;
    selfCheckoutSession: Record<string, any>;
}>;
/**
 * Add a member to a self checkout session
 * @param {Object} body - Config for the method.
 * @param {Object} opts - Additional options
 */
export declare const addMemberToSelfCheckoutSession: (body?: {
    data?: Record<string, any>;
    selfCheckoutSession?: Record<string, any>;
}, opts?: MedipassRequestOpts) => Promise<{
    selfCheckoutSession: Record<string, any>;
}>;
/**
 * Add a health fund account to a self checkout session
 * @param {Object} body - Config for the method.
 * @param {Object} opts - Additional options
 */
export declare const addHealthFundAccountToSelfCheckoutSession: (body: {
    data?: Record<string, any>;
    funder: Record<string, any>;
    selfCheckoutSession: Record<string, any>;
}, opts?: MedipassRequestOpts) => Promise<{
    healthFundAccount: Record<string, any> | undefined;
    selfCheckoutSession: Record<string, any>;
}>;
/**
 * Delete payment method
 * @param {String} paymentMethodId - Payment method ID
 * @param {Object} opts - Additional options
 */
export declare const deletePaymentMethod: (paymentMethodId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
