import type { MedipassRequestOpts } from '../types';
/**
 * Create a business service
 * @param {String} businessId - Business ID
 * @param {String} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessService: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a business practice service
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessPracticeService: (businessId: string, practiceId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete business service
 * @param {String} businessId - Business ID
 * @param {String} serviceId - Service ID
 * @param {Object} opts - Additional options
 */
export declare const deleteBusinessService: (businessId: string, serviceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business service
 * @param {String} businessId - Business ID
 * @param {String} serviceId - Service ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessService: (businessId: string, serviceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business services
 * @param {String} businessId - Business ID
 * @param {String} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessServices: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice service
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} serviceId - Service ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeService: (businessId: string, practiceId: string, serviceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice services
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeServices: (businessId: string, practiceId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice staff member services
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {String} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeStaffMemberServices: (businessId: string, practiceId: string, staffId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice staff member service
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {String} serviceId - Service ID
 * @param {String} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeStaffMemberService: (businessId: string, practiceId: string, staffId: string, serviceId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business staff member services
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessStaffMemberServices: (businessId: string, staffId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update a business service
 * @param {String} businessId - Business ID
 * @param {String} serviceId - Service ID
 * @param {String} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateBusinessService: (businessId: string, serviceId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
