import type { MedipassRequestOpts } from '../types';
/**
 *
 * This will kick off a worker that will generate the file and return an S3 file ID.
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const initiateBusinessSettlementExport: (businessId: string, query: {
    from?: string;
    fromFilterOptionIds?: string;
    includesFilterOptionIds?: string;
    practiceIds?: string;
    to?: string;
    settlementSummaryIds?: string;
}, opts?: MedipassRequestOpts) => Promise<{
    s3FileId: string;
}>;
/**
 * Get business settlements
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessSettlements: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business settlement summaries
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessSettlementSummaries: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business settlements summaries by period
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessSettlementSummariesByPeriod: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get a business's settlement summary by Id
 * @param {String} businessId - Business ID
 * @param {String} settlementSummaryId - Settlement ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessSettlementSummaryById: (businessId: string, settlementSummaryId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business settlement summaries search options
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessSettlementSummariesSearchOptions: (businessId: string, query?: Object, opts?: MedipassRequestOpts) => Promise<Object>;
