import type { MedipassRequestOpts, StaffMember } from '../types';
/**
 * Create business staff member
 * @param {String} businessId - Organisation ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessStaffMember: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create organisation staff member
 * @param {String} organisationId - Organisation ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createOrganisationStaffMember: (organisationId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete business staff member
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const deleteBusinessStaffMember: (businessId: string, staffId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete business staff member email
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const deleteBusinessStaffMemberEmail: (businessId: string, staffId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business staff member
 * @param {Object} businessId - Business ID
 * @param {Object} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessStaffMember: (businessId: string, staffId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business staff member roles
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} roleFullName - Role
 * @param {Object} opts - Additional options
 */
export declare const getBusinessStaffMemberRoles: (businessId: string, staffId: string, roleFullName: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice staff member
 * @param {Object} businessId - Business ID
 * @param {Object} practiceId - Practice ID
 * @param {Object} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeStaffMember: (businessId: string, practiceId: string, staffId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice staff member modalities
 * @param {Object} businessId - Business ID
 * @param {Object} practiceId - Practice ID
 * @param {Object} staffId - Staff ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeStaffMemberModalities: (businessId: string, practiceId: string, staffId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Array<Record<string, any>>>;
/**
 * Get business practice staff members
 * @param {Object} businessId - Business ID
 * @param {Object} practiceId - Practice ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeStaffMembers: (businessId: string, practiceId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business form practice staff members
 * @param {Object} businessId - Business ID
 * @param {Object} formId - Form ID
 * @param {Object} practiceId - Practice ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessFormPracticeStaffMembers: (businessId: string, formId: string, practiceId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business service staff members
 * @param {Object} businessId - Business ID
 * @param {Object} serviceId - Service ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessServiceStaffMembers: (businessId: string, serviceId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business staff members
 * @param {Object} opts - Additional options
 */
export declare const getBusinessStaffMembers: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business staff upload urls
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} contentType - Mime type
 * @param {Object} opts - Additional options
 */
export declare const getBusinessStaffUploadUrl: (businessId: string, staffId: string, contentType: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get organisation staff members
 * @param {String} organisationId - Organisation ID
 * @param {Object} opts - Additional options
 */
export declare const getOrganisationStaffMembers: (organisationId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get staff member
 * @param {String} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const getStaffMember: (staffId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Grant business practice staff role
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {String} roleFullName - Role
 * @param {Object} opts - Additional options
 */
export declare const grantBusinessPracticeStaffRole: (businessId: string, practiceId: string, staffId: string, roleFullName: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Grant business practice staff role
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} roleFullName - Role
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const grantBusinessStaffRole: (businessId: string, staffId: string, roleFullName: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Invite a new business staff member
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const inviteNewBusinessStaffMember: (businessId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Invite business staff
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} opts - Additional options
 */
export declare const inviteBusinessStaffMember: (businessId: string, staffId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Revoke business practice staff role
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {String} roleFullName - Role
 * @param {Object} opts - Additional options
 */
export declare const revokeBusinessPracticeStaffRole: (businessId: string, practiceId: string, staffId: string, roleFullName: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Revoke business practice staff role
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} roleFullName - Role
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const revokeBusinessStaffRole: (businessId: string, staffId: string, roleFullName: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update business staff member
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateBusinessStaffMember: (businessId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create or resend a magic link to update current staff's email
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateBusinessStaffMemberEmail: (businessId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update organisation staff member
 * @param {String} organisationId - Organisation ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateOrganisationStaffMember: (organisationId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Verify staff member
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const verifyStaffMember: (staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Clone staff member into another business
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const cloneStaffMemberIntoBusiness: (staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Check if email exists
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const checkStaffMemberEmailExists: (businessId: string, query: {
    email: string;
}, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create business staff provider set item
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createStaffProviderSetItem: (businessId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<StaffMember>;
/**
 * Update business staff provider set item
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} providerSetItemId - Provider set item ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateStaffProviderSetItem: (businessId: string, staffId: string, providerSetItemId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<StaffMember>;
/**
 * Delete business staff provider set item
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} providerSetItemId - Provider set item ID
 * @param {Object} opts - Additional options
 */
export declare const deleteStaffProviderSetItem: (businessId: string, staffId: string, providerSetItemId: string, opts?: MedipassRequestOpts) => Promise<StaffMember>;
/**
 * Create business staff provider registration
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createStaffProviderRegistration: (businessId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<StaffMember>;
/**
 * Update business staff provider registration
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} providerRegistrationId - Provider registration ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateStaffProviderRegistration: (businessId: string, staffId: string, providerRegistrationId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<StaffMember>;
/**
 * Delete business staff provider registration
 * @param {String} businessId - Business ID
 * @param {String} staffId - Staff ID
 * @param {String} providerRegistrationId - Provider registration ID
 * @param {Object} opts - Additional options
 */
export declare const deleteStaffProviderRegistration: (businessId: string, staffId: string, providerRegistrationId: string, opts?: MedipassRequestOpts) => Promise<StaffMember>;
/**
 * Gets a list of providers and their current status.
 * @param {String} businessId - Business ID
 * @param {Object} query - Query parameters
 * @param {Object} opts - Additional options
 */
export declare const getProvidersStatus: (businessId: string, query: {
    providerNumber?: string;
}, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
