import type { MedipassRequestOpts } from '../types';
/**
 * Get transaction statistics for a health fund
 * @param {String} healthFundId - Health fund ID
 * @param {String} from - From date in YYYY-MM-DD format
 * @param {String} to - To date in YYYY-MM-DD format
 * @param {Object} query - Extra query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTransactionStatsForHealthFundId: (healthFundId: string, from: string | null | undefined, to: string | null | undefined, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Array<Record<string, any>>>;
/**
 * Get transaction statistics as CSV for a health fund
 * @param {String} healthFundId - Health fund ID
 * @param {String} from - From date in YYYY-MM-DD format
 * @param {String} to - To date in YYYY-MM-DD format
 * @param {Object} query - Extra query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTransactionStatsCSVForHealthFundId: (healthFundId: string, from: string | null | undefined, to: string | null | undefined, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund account stats for a health fund
 * @param {String} healthFundId - Health fund ID
 * @param {String} from - From date in YYYY-MM-DD format
 * @param {String} to - To date in YYYY-MM-DD format
 * @param {Object} query - Extra query parameters
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundAccountStatsForHealthFundId: (healthFundId: string, from: string | null | undefined, to: string | null | undefined, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction statistics for a business
 * @param {String} businessId - Business ID
 * @param {String} from - From date in YYYY-MM-DD format
 * @param {String} to - To date in YYYY-MM-DD format
 * @param {Object} query - Extra query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTransactionStatsForBusiness: (businessId: string, from: string | null | undefined, to: string | null | undefined, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction statistics for a practice
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} from - From date in YYYY-MM-DD format
 * @param {String} to - To date in YYYY-MM-DD format
 * @param {Object} query - Extra query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTransactionStatsForPractice: (businessId: string, practiceId: string, from: string | null | undefined, to: string | null | undefined, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction statistics for an organisation
 * @param {String} organisationId - Organisation ID
 * @param {String} from - From date in YYYY-MM-DD format
 * @param {String} to - To date in YYYY-MM-DD format
 * @param {Object} query - Extra query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTransactionStatsForOrganisation: (organisationId: string, from: string | null | undefined, to: string | null | undefined, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
