import type { MedipassRequestOpts } from '../types';
export declare const pathTerminalsByBusinessId: (businessId: string) => string;
export declare const pathTerminalsByPracticeId: (businessId: string, practiceId: string) => string;
export declare const pathTerminalByTerminalId: (businessId: string, practiceId: string, terminalId: string) => string;
export declare const pathResetTerminal: (businessId: string, practiceId: string, terminalId: string) => string;
export declare const pathClientTokenByPracticeId: (businessId: string, practiceId: string) => string;
export declare const pathTerminalAuthByBusinessId: (businessId: string, terminalId: string) => string;
/**
 * Register a terminal
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const registerTerminal: (businessId: string, practiceId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get terminals for a business
 * @param {String} businessId - Business ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessTerminals: (businessId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get registered terminals for a practice
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTerminals: (businessId: string, practiceId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get terminal by terminalId
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} terminalId - Terminal ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getTerminal: (businessId: string, practiceId: string, terminalId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update terminal by terminalId
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} terminalId - Terminal ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateTerminal: (businessId: string, practiceId: string, terminalId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete terminal by terminalId
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} terminalId - Terminal ID
 * @param {Object} opts - Additional options
 */
export declare const deleteTerminal: (businessId: string, practiceId: string, terminalId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get client token
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} opts - Additional options
 */
export declare const getClientToken: (businessId: string, practiceId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Reset terminal by terminalId - only to be used on tyro simulato terminals
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} terminalId - Terminal ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const resetTerminal: (businessId: string, practiceId: string, terminalId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * De-authenticate terminal by terminalId
 * @param {String} businessId - Business ID
 * @param {String} terminalId - Terminal ID
 * @param {Object} opts - Additional options
 */
export declare const deauthenticateTerminal: (businessId: string, terminalId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
