import type { MedipassRequestOpts, Transaction } from '../types';
/**
 * Approve a transaction
 * @param {String} transactionId - Transaction ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const approveTransaction: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Assign health fund transactions
 * @param {String} healthFundId - Health fund ID
 * @param {Object} opts - Additional options
 */
export declare const assignHealthFundTransactions: (healthFundId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Assign health fund transaction to self
 * @param {String} healthFundId - Health fund ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const assignHealthFundTransactionToSelf: (healthFundId: string, transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Assign transaction to self
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const assignTransactionToSelf: (transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Cancel a transaction
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const cancelTransaction: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Cancel a business transaction
 * @param {String} businessId - Business ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const cancelBusinessTransaction: (businessId: string, transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create an invoice for a business
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessPracticeStaffMemberInvoice: (businessId: string, practiceId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create an invoice for a business
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessPracticeInvoice: (businessId: string, practiceId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a quote for a business
 * @param {String} businessId - Business ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessTransactionQuote: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a quote for a staff
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createBusinessPracticeStaffMemberQuote: (businessId: string, practiceId: string, staffId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a payment for a transaction
 * @param {String} transactionId - TransactionId
 * @param {String} source - Payment source (e.g. 'mastercard')
 * @param {String} nonce - Nonce (or client token)
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createPayment: (transactionId: string, source?: string, nonce?: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a payment request for a transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createPaymentRequest: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Complete a quote
 * @param {String} transactionId - Transaction ID
 * @param {Object} memberId - Member ID
 * @param {Object} opts - Additional options
 */
export declare const completeQuote: (transactionId: string, memberId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete a transaction tag
 * @param {String} transactionId - Transaction ID
 * @param {String} tagId - Tag ID
 * @param {Object} opts - Additional options
 */
export declare const deleteTransactionTag: (transactionId: string, tagId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Delete a transaction
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const deleteTransaction: (transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business transactions
 * @param {String} businessId - Business ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessTransactions: (businessId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business transaction
 * @param {String} businessId - Business ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessTransaction: (businessId: string, transactionId: string, query?: {
    includeDeleted: boolean;
} | null | undefined, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business transaction by invoice reference
 * @param {String} businessId - Business ID
 * @param {String} invoiceReference - Invoice reference
 * @param {Object} opts - Additional options
 */
export declare const getBusinessTransactionByInvoiceReference: (businessId: string, invoiceReference: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business transaction payment report
 * @param {String} businessId - Business ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessTransactionPaymentReport: (businessId: string, transactionId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business transaction processing report
 * @param {String} businessId - Business ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessTransactionProcessingReport: (businessId: string, transactionId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business practice transactions
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeTransactions: (businessId: string, practiceId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business staff transactions
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getBusinessPracticeStaffTransactions: (businessId: string, practiceId: string, staffId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transactions by health fund
 * @param {String} healthFundId - Health fund ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTransactionsForHealthFund: (healthFundId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction by transaction ID and health fund ID
 * @param {String} healthFundId - Health fund ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundTransaction: (healthFundId: string, transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transactions by member
 * @param {String} memberId - Health fund ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getTransactionsByMember: (memberId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get health fund member transactions
 * @param {String} healthFundId - Health fund ID
 * @param {String} memberId - Member ID
 * @param {Object} query - query parameters
 * @param {Object} opts - Additional options
 */
export declare const getHealthFundMemberTransactions: (healthFundId: string, memberId: string, query?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction by transaction ID.
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const getTransactionByTransactionId: (transactionId: string, query?: {
    includeDeleted: boolean;
} | null | undefined, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction PDF
 * @param {String} transactionId - Transaction ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getTransactionPDF: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get transaction claim PDF
 * @param {String} transactionId - Transaction ID
 * @param {String} claimId - Claim ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const getTransactionClaimPDF: (transactionId: string, claimId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * TODO: Use this endpoint for all funder claims, once the funder is supported in the API,
 * replacing the legacy `getTransactionClaimPDF`.
 *
 * Get ECLIPSE transaction claim PDF
 * @param {Object} body - Request body including `transactionId` and `claimId`
 * @param {Object} opts - Additional options
 */
export declare const getTransactionClaimPdfV2: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Reply to a quote
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const replyToQuote: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send receipt
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const sendReceipt: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Submit an invoice
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const submitInvoice: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateTransaction: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Validate a transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} opts - Additional options
 */
export declare const validateTransaction: (transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Submits a Bridge's claim response to transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const submitTransactionBridgeClaim: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Submits a Bridge's payment response to transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const submitTransactionBridgePayment: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Trigger's a bridge request for a transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const triggerBridge: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create invoice
 * @param {String} businessId - BusinessId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createInvoice: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create or send a claim
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createSendClaim: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Update a claim
 * @param {String} transactionId - TransactionId
 * @param {String} claimId - ClaimId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const updateClaim: (transactionId: string, claimId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Complete a transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} opts - Additional options
 */
export declare const completeTransaction: (transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Approves a claim
 * @param {String} transactionId - TransactionId
 * @param {String} claimId - ClaimId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const approveClaim: (transactionId: string, claimId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Cancels a claim
 * @param {String} transactionId - Transaction ID
 * @param {String} claimId - Claim ID
 * @param {Object} opts - Additional options
 */
export declare const cancelClaim: (transactionId: string, claimId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Submit a claim
 * @param {String} transactionId - TransactionId
 * @param {String} claimId - ClaimId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const submitClaim: (transactionId: string, claimId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Save claim details
 * @param {String} transactionId - Transaction ID
 * @param {String} claimId - Claim ID
 * @param {Object} opts - Additional options
 */
export declare const saveClaimDetails: (transactionId: string, claimId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create payment
 * @param {String} transactionId - Transaction ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const pay: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send a processing request
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const sendProcessingRequest: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Cancel invoice
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const cancelInvoice: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get payment link
 * @param {String} transactionId - TransactionId
 * @param {Object} opts - Additional options
 */
export declare const getPaymentLink: (transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Refund transaction
 * @param {String} businessId - BusinessId
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const refundByBusiness: (businessId: string, transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Refund transaction
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const refund: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Save invoice as draft
 * @param {String} businessId - BusinessId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const saveDraft: (businessId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Convert draft to an invoice
 * @param {String} transactionId - Transaction ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const convertDraft: (transactionId: string, body?: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Transaction>;
/**
 * Archive an invoice
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const archive: (transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Unarchive an invoice
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const unarchive: (transactionId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send terminal input
 * @param {String} transactionId - Transaction ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const terminalInput: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Send terminal cancellation
 * @param {String} transactionId - Transaction ID
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const terminalCancellation: (transactionId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
export interface RefundPaymentRequestBody {
    refundAmount: string;
    refundReason: string;
    terminal?: {
        terminalId: string;
        merchantId: string;
    };
}
/**
 * Refund transaction's payment
 * @param {String} transactionId - TransactionId
 * @param {String} paymentId - PaymentId
 * @param {RefundPaymentRequestBody} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const refundPayment: (transactionId: string, paymentId: string, body: RefundPaymentRequestBody, opts?: MedipassRequestOpts) => Promise<Transaction>;
/**
 * Perform a standalone refund of a transaction's payment
 * @param {String} transactionId - TransactionId
 * @param {String} paymentId - PaymentId
 * @param {RefundPaymentRequestBody} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const standaloneRefund: (transactionId: string, paymentId: string, body: RefundPaymentRequestBody, opts?: MedipassRequestOpts) => Promise<Transaction>;
/**
 * Void transaction's payment
 * @param {String} transactionId - TransactionId
 * @param {String} paymentId - PaymentId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const voidPayment: (transactionId: string, paymentId: string, body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create ECLIPSE invoice - In Patient
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createEclipseInPatientInvoice: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create ECLIPSE invoice - Overseas
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createEclipseOverseasInvoice: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create ECLIPSE invoice - Online Eligibility Check
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createEclipseOnlineEligibilityCheckInvoice: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business ECLIPSE transaction payment report
 * @param {String} businessId - Business ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessEclipseTransactionPaymentReport: (businessId: string, transactionId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Get business ECLIPSE transaction processing report
 * @param {String} businessId - Business ID
 * @param {String} transactionId - Transaction ID
 * @param {Object} opts - Additional options
 */
export declare const getBusinessEclipseTransactionProcessingReport: (businessId: string, transactionId: string, query: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Reconciles a claim
 * @param {String} transactionId - TransactionId
 * @param {String} claimId - ClaimId
 * @param {Object} opts - Additional options
 */
export declare const reconcileClaim: (transactionId: string, claimId: string, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Save draft for ECLIPSE invoice - In Patient
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const saveDraftEclipseInPatientInvoice: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Save draft ECLIPSE invoice - Overseas
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const saveDraftEclipseOverseasInvoice: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create PHI invoice
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createPhiInvoice: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create a PHI quote
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createPhiQuote: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
export interface EmailInvoiceRequestBody {
    emailTo: string[];
    message: string;
}
/**
 * Email invoice
 * @param {String} transactionId - TransactionId
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const emailInvoice: (transactionId: string, body: EmailInvoiceRequestBody, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
/**
 * Create invoices ( Smart Invoice )
 * @param {Object} body - Request body
 * @param {Object} opts - Additional options
 */
export declare const createManualInvoice: (body: Record<string, any>, opts?: MedipassRequestOpts) => Promise<Record<string, any>>;
