/**
 * Upload health fund form file to S3
 * @param {String} healthFundId - Health fund ID
 * @param {Object} file - File
 */
export declare const uploadHealthFundFormFileToS3: (healthFundId: string, file: any, opts?: Record<string, any>) => Promise<Record<string, any>>;
/**
 * Upload scanned application to S3
 * @param {String} businessId
 * @param {String} practiceId
 * @param {String} formId
 * @param {Object} file - File
 */
export declare const uploadScannedApplicationToS3: (businessId: string, practiceId: string, formId: string, file: any, opts?: Record<string, any>) => Promise<Record<string, any>>;
/**
 * Upload claim attachment to S3
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {String} staffId - Staff ID
 * @param {Object} file - File
 */
export declare const uploadClaimAttachmentToS3: (businessId: string, practiceId: string, staffId: string, healthFundId: string, file: any, opts?: Record<string, any>) => Promise<Record<string, any>>;
/**
 * Upload business practice image to S3
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Practice ID
 * @param {Object} file - File
 */
export declare const uploadBusinessPracticeImageToS3: (businessId: string, practiceId: string, file: any) => Promise<Record<string, any>>;
/**
 * Upload business staff image to S3
 * @param {String} businessId - Business ID
 * @param {String} practiceId - Staff ID
 * @param {Object} file - File
 */
export declare const uploadBusinessStaffMemberImageToS3: (businessId: string, staffId: string, file: any) => Promise<Record<string, any>>;
/**
 * Upload invoice scan to S3
 * @param {String} businessId - Business ID
 * @param {Object} file - File
 */
export declare const uploadInvoiceScanToS3: (businessId: string, file: any, opts?: Record<string, any>) => Promise<Record<string, any>>;
/**
 * Upload bulk upload CSV to S3
 * @param {String} businessId - Business ID
 * @param {Object} file - File
 */
export declare const uploadBulkUploadCSVToS3: (businessId: string, file: any, opts?: Record<string, any>) => Promise<Record<string, any>>;
/**
 * Upload business kyc trust document to S3
 * @param {String} businessId - Business ID
 * @param {Object} file - File
 */
export declare const uploadKycTrustDocumentToS3: (businessId: string, file: any, opts?: Record<string, any>) => Promise<Record<string, any>>;
/**
 * Upload attachment to S3
 * @param {String} businessId - Business ID
 * @param {String} healthFundId - Health fund ID
 * @param {File} file - File
 */
export declare const uploadAttachmentToS3: (businessId: string, healthFundId: string, file: File, opts?: Record<string, any>) => Promise<{
    s3Url: string;
    s3SignedUrlId: string;
}>;
/**
 * Upload aged care attachment to S3
 * @param {String} businessId - Business ID
 * @param {File} file - File
 */
export declare const uploadAgedCareAttachmentToS3: (businessId: string, file: File, opts?: Record<string, any>) => Promise<{
    s3Url: string;
    s3SignedUrlId: string;
}>;
