import type { PaginatedQuery, PaginatedResponse } from 'types';
import type { StaffMember } from './staff-member';
export interface GetCareRecipientDetailsQuery {
    registeredProviderId?: string;
    businessId?: string;
}
export interface CareRecipientDetailsResponse {
    careRecipientId: string;
    firstName: string;
    middleName: string;
    lastName: string;
    birthDate: string;
    gender: string;
    myAgedCareGatewayId: string;
    sparcId: string;
    firstNations: string;
    homeless: string;
    careLeavers: string;
    careFindersProgram: string;
    modifiedMonashModelRating: string;
    anaccClassifications: Array<{
        classification: string;
        classificationText: string;
        classificationTypeText: string;
        careType: string;
        careSubType: string;
        startDate: string;
        endDate: string;
        updatedAtDateTime: string;
    }>;
    packages: Array<{
        assignedLevel: string;
        startDate: string;
        endDate: string;
    }>;
    assessments: Array<{
        assessmentId: string;
        thirdPartyId: string;
        acatId: string;
        status: string;
        approvalDate: string;
        careDetails: [];
    }>;
    careExtensions: Array<{
        careType: string;
        careSubType: string;
        numberOfDaysExtended: number;
        dateExtensionCommences: string;
    }>;
    placeAllocations: Array<{
        placeIdentifier: string;
        effectiveStartDate: string;
        effectiveEndDate: string;
        status: string;
        statusReason: string;
        currentPlaceIndicator: string;
        updatedAtDateTime: string;
    }>;
    classifications: Array<{
        classificationType: string;
        classificationCode: string;
        classificationText: string;
        effectiveStartDate: string;
        effectiveEndDate: string;
        updatedAtDateTime: string;
    }>;
    approvedServices: Array<{
        serviceGroupId: string;
        serviceGroupText: string;
        serviceTypeId: string;
        serviceTypeText: string;
        serviceId: string;
        serviceText: string;
        effectiveStartDate: string;
        effectiveEndDate: string;
        updatedAtDateTime: string;
    }>;
    supplements: Array<{
        supplementType: string;
        startDate: string;
        endDate: string;
        rate: string;
        updatedAtDateTime: string;
    }>;
    messages: Array<{
        type: string;
        message: string;
    }>;
}
export interface GetServiceProviderDetailsQuery {
    businessId?: string;
    registeredProviderId?: string;
}
export interface ServiceProviderDetailsResponse {
    serviceProviderId: string;
    serviceNapsId: string;
    serviceProviderName: string;
    registeredProviderId: string;
    programCode: string;
    status: string;
    statusEffectiveDate: string;
    addresses: Array<{
        type: string;
        streetLine1: string;
        streetLine2: string;
        city: string;
        state: string;
        country: string;
        postcode: string;
        validFrom: string;
        validTo: string;
    }>;
    registrationCategories: Array<{
        categoryCode: string;
        categoryText: string;
        startDate: string;
        endDate: string;
        updatedAtDateTime: string;
    }>;
    registeredServiceTypes: Array<{
        serviceGroupId: string;
        serviceGroupText: string;
        serviceTypeId: string;
        serviceTypeText: string;
        serviceTypeStartDate: string;
        serviceTypeEndDate: string;
        updatedAtDateTime: string;
    }>;
}
export interface SearchCareRecipientsQuery {
    businessId?: string;
    registeredProviderId?: string;
    firstName?: string;
    lastName?: string;
    birthDate?: string;
    gender?: string;
    myAgedCareGatewayId?: string;
    sparcId?: string;
    sortFields?: string;
}
export declare type SearchCareRecipient = {
    careRecipientId: string;
    birthDate: string;
    firstName: string;
    lastName: string;
    middleName: string;
    gender: string;
    myAgedCareGatewayId: string;
    sparcId: string;
};
export declare type SearchCareRecipientsResponse = PaginatedResponse<SearchCareRecipient>;
export declare type CreateAgedCareInvoiceBody = {
    draftTransactionId?: string;
    businessId: string;
    invoiceReference: string;
    patient: {
        identity?: {
            _id?: string;
        };
    };
    serviceProvider: {
        providerSetItemId?: string;
    };
    claimItems: Array<{
        serviceId?: string;
        serviceDateString?: string;
        chargeAmount?: string;
        quantity?: number;
        reference?: string;
        fundingSource?: string;
        deliveredByThirdParty?: boolean;
        itemOrWraparound?: string;
        itemDescriptionCode?: string;
        itemDescription?: string;
        itemCategoryCode?: string;
        itemCategoryText?: string;
        itemCategory?: string;
        wraparoundDescriptionCode?: string;
        wraparoundDescription?: string;
        prescribedItem?: string;
        purchaseMethodType?: string;
        loanedByOrganisationName?: string;
        loanedByInvoiceNumber?: string;
        healthProfessionalTypeCode?: string;
        healthProfessionalTypeOther?: string;
        itemFirstPayment?: boolean;
        lateSubmissionReasonCode?: string;
        lateSubmissionJustification?: string;
        attachments?: Array<{
            s3SignedUrlId: string;
            filename: string;
            type: 'INVOICE' | 'PRESC' | 'QUOTE' | 'RECEIPT' | 'OTHER';
        }>;
    }>;
};
export declare type AgedCareInvoice = {
    _id: string;
    invoiceId: string;
    serviceNapsId: string;
    serviceProviderId: string;
    externalReferenceId: string;
    status: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    items: Array<{
        itemId: string;
        externalReferenceId: string;
        itemStatus: string;
        careRecipientId: string;
        careRecipientFirstName: string;
        careRecipientLastName: string;
        serviceGroupId: string;
        serviceGroupText: string;
        serviceTypeId: string;
        serviceTypeText: string;
        serviceId: string;
        serviceText: string;
        deliveryDate: string;
        quantity: number;
        pricePerUnit: number;
        unitType: string;
        fundingSource: string;
        fundingSourceText: string;
        attachmentProvided: boolean;
        attachmentRequired: boolean;
        furtherInformationRequired: boolean;
        createdAtDateTime: string;
        updatedAtDateTime: string;
    }>;
};
export declare type GetServicesQuery = {
    businessId: string;
};
export declare type AgedCareService = {
    serviceGroupId: string;
    serviceGroupText: string;
    serviceTypeId: string;
    serviceTypeText: string;
    serviceId: string;
    serviceText: string;
    participantContributionCategory: string;
    unitType: string;
    items: Array<{
        functionCode: string;
        functionText: string;
        itemId: string;
        itemText: string;
        units: Array<string>;
        freeTextRequired: boolean;
    }>;
    wraparoundServices: Array<{
        wraparoundServiceId: string;
        wraparoundServiceText: string;
        units: Array<string>;
        freeTextRequired: boolean;
    }>;
    itemCategories: Array<{
        itemCategoryCode: string;
        itemCategoryText: string;
        freeTextRequired: boolean;
    }>;
    classifications: Array<{
        classificationType: string;
        classificationCode: string;
        classificationText: string;
    }>;
    healthProfessionalTypes: Array<{
        healthProfessionalTypeCode: string;
        healthProfessionalTypeText: string;
        freeTextRequired: boolean;
    }>;
    effectiveStartDate: string;
    effectiveEndDate: string;
    updatedAtDateTime: string;
};
export declare type OnboardRequestBody = {
    businessId?: string;
    registeredProviderId: string;
    orgId: string;
    otac: string;
    deviceName: string;
};
export declare type OnboardResponse = StaffMember;
export declare type GetRegisteredProvidersQuery = {
    businessId?: string;
};
export declare type RegisteredProvider = {
    providerId: string;
    providerNapsId: string;
    providerName: string;
    addresses: Array<{
        type: string;
        streetLine1: string;
        streetLine2: string;
        city: string;
        state: string;
        postcode: string;
        country: string;
        validFrom: string;
        validTo: string;
    }>;
    contacts: Array<{
        firstName: string;
        middleName: string;
        lastName: string;
        phoneNumber: string;
        email: string;
        validFrom: string;
        validTo: string;
    }>;
    services: Array<{
        serviceId: string;
        serviceNapsId: string;
        providerId: string;
        serviceName: string;
        careTypeCode: string;
        operationalStatus: string;
    }>;
};
export declare type GetRegisteredProvidersResponse = Array<RegisteredProvider>;
export declare type GetServiceProviderAccountSummaryQuery = {
    businessId?: string;
    periodStartDate?: string;
    periodEndDate?: string;
};
export declare type ServiceProviderAccountSummary = {
    serviceProviderId: string;
    serviceNapsId: string;
    periodStartDate: string;
    periodEndDate: string;
    heldoverPreviousPeriod: number;
    transactionDetail: Array<{
        date: string;
        description: string;
        amount: number;
        transactionType: string;
        transactionReference: string;
        updatedAtDateTime: string;
    }>;
    heldoverAmount: number;
};
export declare type ServiceProviderAccountSummaryResponse = Array<ServiceProviderAccountSummary>;
export declare type GetClaimsQuery = PaginatedQuery & {
    fromDate?: string;
    toDate?: string;
};
export declare type AgedCareClaimStatus = 'BeingCalculated' | 'PendingApproval' | 'Cancelled' | 'Approved' | 'Paid';
export declare type AgedCareClaim = {
    _id: string;
    businessId: string;
    staff: {
        _id: string;
        firstName: string;
        lastName: string;
        abn?: string;
    };
    practice: {
        _id: string;
        addressPrefix?: string;
        subpremise?: string | null;
        streetNumber?: string;
        route?: string;
        address?: string;
        postcode?: string;
        city?: string;
        state?: string;
        country?: string;
        countryCode?: string;
        email?: string;
        abn?: string;
    };
    serviceProviderId: string;
    claimId: string;
    amountPaid: number;
    amountPaidString: string;
    paymentDateString: string;
    status: AgedCareClaimStatus;
    agedCareCreated: string;
    agedCareUpdated: string;
    created: string;
    modified: string;
};
export declare type GetClaimQuery = {
    businessId?: string;
};
export declare type GetPaymentStatementQuery = {
    businessId?: string;
    serviceProviderId: string;
    claimId: string;
};
export declare type AgedCarePaymentStatement = {
    id: string;
    serviceProviderId: string;
    serviceNapsId: string;
    registeredProviderId: string;
    registeredProviderName: string;
    registeredProviderABN: string;
    paymentDate: string;
    updatedAtDateTime: string;
    summary: {
        categoryItems: Array<{
            description: string;
            amount: number;
            code: string;
        }>;
        heldoverPreviousPeriod: number;
        commonwealthUnspent: number;
        compensationReduction: number;
        careRecipientIndividualContribution: number;
        claimTotal: number;
        totalPaid: number;
        outstandingHeldover: number;
    };
    paymentItems: Array<{
        invoiceId: string;
        itemId: string;
        invoiceExternalReferenceId: string;
        invoiceItemExternalReferenceItemId: string;
        careRecipientId: string;
        careRecipientFirstName: string;
        careRecipientLastName: string;
        deliveryDate: string;
        serviceGroupId: string;
        serviceGroupText: string;
        serviceTypeId: string;
        serviceTypeText: string;
        serviceId: string;
        serviceText: string;
        itemDescriptionCode: string;
        itemDescriptionText: string;
        wraparoundDescriptionCode: string;
        wraparoundDescriptionText: string;
        quantity: number;
        pricePerUnit: number;
        unitType: string;
        invoiceAmount: number;
        compensationReduction: number;
        individualContributionAmount: number;
        paymentDetermination: number;
        budgets: Array<{
            budgetTypeCode: string;
            budgetTypeText: string;
            amount: number;
        }>;
    }>;
    notes: Array<{
        noteType: string;
        note: string;
    }>;
};
export declare type AgedCareUploadUrlRequestBody = {
    businessId?: string;
    contentType: string;
    contentLength: number;
};
export declare type AgedCareUploadUrlResponse = {
    signedPost: {
        fields: {
            key: string;
            bucket: string;
            'X-Amz-Algorithm': string;
            'X-Amz-Credential': string;
            'X-Amz-Date': string;
            'X-Amz-Security-Token': string;
            'X-Amz-Signature': string;
            'Content-Type': string;
            'x-amz-server-side-encryption': string;
            'x-amz-server-side-encryption-aws-kms-key-id': string;
        };
        url: string;
    };
    s3Url: string;
    s3SignedUrlId: string;
};
export declare type AgedCareTransactionAttachmentType = 'INVOICE' | 'PRESC' | 'QUOTE' | 'RECEIPT' | 'OTHER';
export declare type CreateInvoiceItemAttachmentRequestBody = {
    businessId?: string;
    s3SignedUrlId: string;
    filename: string;
    type: AgedCareTransactionAttachmentType;
};
export declare type CreateInvoiceItemAttachmentResponse = {
    type: string;
    typeText: string;
    id: string;
    filename: string;
    mimeType: string;
    createdAtDateTime: string;
};
export declare type GetTransactionFilesQuery = PaginatedQuery & {
    businessId?: string;
};
export declare type AgedCareTransactionFile = {
    _id: string;
    businessId: string;
    funderId: string;
    transactionId: string;
    itemId: string;
    s3SignedUrlId: string;
    status: string;
    filename: string;
    category: AgedCareTransactionAttachmentType;
    created: string;
    modified: string;
};
export declare type GetInvoiceQuery = {
    businessId?: string;
};
export declare type GetPaymentItemsReportQuery = PaginatedQuery & {
    businessId?: string;
    invoiceId?: string;
};
export declare type AgedCarePaymentItemsReport = {
    invoiceId: string;
    itemId: string;
    invoiceExternalReferenceId: string;
    invoiceItemExternalReferenceItemId: string;
    serviceProviderId: string;
    serviceNapsId: string;
    careRecipientId: string;
    claimSubmissionDate: string;
    claimApprovedDate: string;
    paymentDate: string;
    deliveryDate: string;
    serviceGroupId: string;
    serviceGroupText: string;
    serviceTypeId: string;
    serviceTypeText: string;
    serviceId: string;
    serviceText: string;
    itemDescriptionCode: string;
    itemDescriptionText: string;
    wraparoundDescriptionCode: string;
    wraparoundDescriptionText: string;
    quantity: number;
    pricePerUnit: number;
    unitType: string;
    invoiceAmount: number;
    compensationReduction: number;
    individualContributionAmount: number;
    paymentDetermination: number;
    updatedAtDateTime: string;
    budgets: Array<{
        budgetTypeCode: string;
        budgetTypeText: string;
        amount: number;
    }>;
};
export declare type AgedCareEnteralFeedingSupplementAttachmentType = 'AC011' | 'MED_CERT' | 'INVOICE' | 'OTH_EVENT';
export declare type CreateEnteralFeedingSupplementAttachmentRequestBody = {
    businessId?: string;
    s3SignedUrlId: string;
    filename: string;
    type: AgedCareEnteralFeedingSupplementAttachmentType;
};
export declare type CreateEnteralFeedingSupplementAttachmentResponse = {
    type: string;
    typeText: string;
    id: string;
    filename: string;
    mimeType: string;
    createdAtDateTime: string;
};
export declare type AgedCareOxygenSupplementAttachmentType = 'AC011' | 'MED_CERT' | 'INVOICE' | 'OTH_EVENT';
export declare type CreateOxygenSupplementAttachmentRequestBody = {
    businessId?: string;
    s3SignedUrlId: string;
    filename: string;
    type: AgedCareOxygenSupplementAttachmentType;
};
export declare type CreateOxygenSupplementAttachmentResponse = {
    type: string;
    typeText: string;
    id: string;
    filename: string;
    mimeType: string;
    createdAtDateTime: string;
};
export declare type GetIndividualContributionsQuery = PaginatedQuery & {
    businessId?: string;
    careRecipientId?: string;
    serviceNapsId?: string;
    serviceProviderId?: string;
    effectiveDateFrom?: string;
    effectiveDateTo?: string;
    updatedAtDateTimeFrom?: string;
    updatedAtDateTimeTo?: string;
    sortFields?: string;
};
export declare type IndividualContribution = {
    serviceProviderId: string;
    serviceNapsId: string;
    careRecipientId: string;
    careRecipientFirstName: string;
    careRecipientLastName: string;
    entryDate: string;
    contributionTypeCode: string;
    contributionTypeText: string;
    participantContributionCategoryCode: string;
    participantContributionCategoryText: string;
    contributionPercentage: number;
    startDate: string;
    endDate: string;
    updatedAtDateTime: string;
};
export declare type GetCareRecipientBudgetsQuery = PaginatedQuery & {
    businessId?: string;
    effectiveDateFrom?: string;
    effectiveDateTo?: string;
    sortFields?: string;
};
export declare type GetServiceProviderBudgetsQuery = PaginatedQuery & {
    businessId?: string;
    effectiveDateFrom?: string;
    effectiveDateTo?: string;
    sortFields?: string;
};
export declare type CareRecipientBudget = {
    budgetId: string;
    serviceProviderId: string;
    careRecipientId: string;
    entryDate: string;
    budgetTypeCode: string;
    budgetType: string;
    startDate: string;
    endDate: string;
    total: number;
    available: number;
    used: number;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    status: string;
};
export declare type ServiceProviderBudget = {
    budgetId: string;
    serviceProviderId: string;
    careRecipientId: string;
    entryDate: string;
    budgetTypeCode: string;
    budgetType: string;
    startDate: string;
    endDate: string;
    total: number;
    available: number;
    used: number;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    status: string;
};
export declare type GetBudgetDetailsQuery = {
    businessId?: string;
};
export declare type BudgetDetailsResponse = {
    budgetId: string;
    careRecipientId: string;
    careRecipientName: string;
    budgetTypeCode: string;
    budgetType: string;
    startDate: string;
    endDate: string;
    total: number;
    available: number;
    used: number;
    status: string;
    entitlementItems: Array<{
        itemCode: string;
        description: string;
        amount: number;
        startDate: string;
        endDate: string;
        createdAtDateTime: string;
    }>;
    usage: Array<{
        serviceProviderId: string;
        itemCode: string;
        itemDescription: string;
        invoiceId: string;
        itemId: string;
        amount: number;
        deliveryDate: string;
        updatedAtDateTime: string;
    }>;
};
export interface OxygenSupplement {
    supplementId: string;
    externalReferenceId: string;
    careRecipientId: string;
    careRecipientName: string;
    serviceNapsId: string;
    serviceProviderId: string;
    startDate: string;
    endDate: string;
    oxygenTypeCode: string;
    oxygenTypeText: string;
    status: string;
    channel: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
    attachments: Array<{
        type: string;
        typeText: string;
        id: string;
        filename: string;
        mimeType: string;
        createdAtDateTime: string;
    }>;
}
export interface EnteralFeedingSupplement {
    supplementId: string;
    externalReferenceId: string;
    careRecipientId: string;
    careRecipientName: string;
    serviceNapsId: string;
    serviceProviderId: string;
    startDate: string;
    endDate: string;
    enteralFeedingTypeCode: string;
    enteralFeedingTypeText: string;
    status: string;
    channel: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
    attachments: Array<{
        type: string;
        typeText: string;
        id: string;
        filename: string;
        mimeType: string;
        createdAtDateTime: string;
    }>;
}
export interface GetEnteralFeedingSupplementDetailsQuery {
    businessId?: string;
}
export interface GetOxygenSupplementDetailsQuery {
    businessId?: string;
}
export declare type GetEnteralFeedingSupplementsQuery = PaginatedQuery & {
    businessId?: string;
    serviceNapsId?: string;
    serviceProviderId?: string;
    careRecipientId?: string;
    externalReferenceId?: string;
    startDateFrom?: string;
    startDateTo?: string;
    endDateFrom?: string;
    endDateTo?: string;
    updatedAtDateTimeFrom?: string;
    updatedAtDateTimeTo?: string;
    'sort-fields'?: 'createdAtDateTime' | 'updatedAtDateTime' | 'startDate' | 'careRecipientId';
};
export declare type GetOxygenSupplementsQuery = PaginatedQuery & {
    businessId?: string;
    serviceNapsId?: string;
    serviceProviderId?: string;
    careRecipientId?: string;
    externalReferenceId?: string;
    startDateFrom?: string;
    startDateTo?: string;
    endDateFrom?: string;
    endDateTo?: string;
    updatedAtDateTimeFrom?: string;
    updatedAtDateTimeTo?: string;
    'sort-fields'?: 'createdAtDateTime' | 'updatedAtDateTime' | 'startDate' | 'careRecipientId';
};
export interface GetEnteralFeedingSupplementsItem {
    supplementId: string;
    externalReferenceId: string;
    careRecipientId: string;
    careRecipientName: string;
    serviceNapsId: string;
    serviceProviderId: string;
    startDate: string;
    endDate: string;
    enteralFeedingTypeCode: string;
    enteralFeedingTypeText: string;
    status: string;
    channel: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
}
export declare type GetEnteralFeedingSupplementsResponse = PaginatedResponse<GetEnteralFeedingSupplementsItem>;
export interface GetOxygenSupplementsItem {
    supplementId: string;
    externalReferenceId: string;
    careRecipientId: string;
    careRecipientName: string;
    serviceNapsId: string;
    serviceProviderId: string;
    startDate: string;
    endDate: string;
    oxygenTypeCode: string;
    oxygenTypeText: string;
    status: string;
    channel: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
}
export declare type GetOxygenSupplementsResponse = PaginatedResponse<GetOxygenSupplementsItem>;
export interface CreateOxygenSupplementRequestBody {
    businessId?: string;
    externalReferenceId?: string;
    careRecipientId: string;
    serviceNapsId: string;
    startDate: string;
    oxygenTypeCode: string;
}
export interface UpdateOxygenSupplementRequestBody {
    businessId?: string;
    externalReferenceId?: string;
    careRecipientId: string;
    serviceNapsId: string;
    startDate: string;
    oxygenTypeCode: string;
}
export interface DeleteOxygenSupplementQuery {
    businessId?: string;
}
export interface CreateEnteralFeedingSupplementRequestBody {
    businessId?: string;
    externalReferenceId?: string;
    careRecipientId: string;
    serviceNapsId: string;
    startDate: string;
    enteralFeedingTypeCode: string;
}
export interface UpdateEnteralFeedingSupplementRequestBody {
    businessId?: string;
    externalReferenceId?: string;
    careRecipientId: string;
    serviceNapsId: string;
    startDate: string;
    enteralFeedingTypeCode: string;
}
export interface DeleteEnteralFeedingSupplementQuery {
    businessId?: string;
}
export interface UpdateEnteralFeedingSupplementEndDateRequestBody {
    businessId?: string;
    careRecipientId: string;
    startDate: string;
    endDate: string;
}
export interface UpdateOxygenSupplementEndDateRequestBody {
    businessId?: string;
    careRecipientId: string;
    startDate: string;
    endDate: string;
}
export interface EndDateEnteralFeedingSupplement {
    careRecipientId: string;
    careRecipientName: string;
    startDate: string;
    endDate: string;
    status: 'Created' | 'Updated' | 'Deleted' | 'Pending approval' | 'Approved' | 'Rejected';
    updatedAtDateTime: string;
}
export interface EndDateOxygenSupplement {
    careRecipientId: string;
    careRecipientName: string;
    startDate: string;
    endDate: string;
    status: 'Created' | 'Updated' | 'Deleted' | 'Pending approval' | 'Approved' | 'Rejected';
    updatedAtDateTime: string;
}
export declare type GetEntriesQuery = PaginatedQuery & {
    businessId?: string;
    serviceNapsId?: string;
    serviceProviderId?: string;
    careRecipientId?: string;
    externalReferenceId?: string;
    entryDateFrom?: string;
    entryDateTo?: string;
    departureDateFrom?: string;
    departureDateTo?: string;
    updatedAtDateTimeFrom?: string;
    updatedAtDateTimeTo?: string;
    'sort-fields'?: 'createdAtDateTime' | 'updatedAtDateTime' | 'entryDate' | 'careRecipientId' | 'externalReferenceId';
};
export interface GetEntriesItem {
    eventId: string;
    status: string;
    channel: string;
    careRecipientName: string;
    serviceNapsId: string;
    serviceProviderId: string;
    careRecipientId: string;
    entryDate: string;
    entryCategoryCode: string;
    entryCategoryText: string;
    externalReferenceId: string;
    departureDate: string;
    departureReasonCode: string;
    departureEventId: string;
    optInSupportAtHomeRates: string;
    centrelinkCrn: string;
    dvaUin: string;
    careLevel: string;
    carerStatus: string;
    awardOrSettlementTypeCode: string;
    unfundedPriorEntryDate: string;
    approvalSighted: string;
    awardOrSettlementTypeText: string;
    departureReasonText: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    address?: {
        streetLine?: string;
        suburb?: string;
        state?: string;
        postcode?: string;
    };
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
}
export declare type GetEntriesResponse = PaginatedResponse<GetEntriesItem>;
export interface GetEntryQuery {
    businessId?: string;
}
export interface GetEntryResponse {
    eventId: string;
    status: string;
    channel: string;
    careRecipientName: string;
    serviceNapsId: string;
    serviceProviderId: string;
    careRecipientId: string;
    entryDate: string;
    entryCategoryCode: string;
    entryCategoryText: string;
    externalReferenceId: string;
    departureDate: string;
    departureReasonCode: string;
    departureEventId: string;
    optInSupportAtHomeRates: string;
    centrelinkCrn: string;
    dvaUin: string;
    careLevel: string;
    carerStatus: string;
    awardOrSettlementTypeCode: string;
    unfundedPriorEntryDate: string;
    approvalSighted: string;
    awardOrSettlementTypeText: string;
    departureReasonText: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    address?: {
        streetLine?: string;
        suburb?: string;
        state?: string;
        postcode?: string;
    };
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
}
export interface UpdateEntryRequestBody {
    businessId?: string;
    serviceNapsId: string;
    careRecipientId: string;
    entryDate: string;
    entryCategoryCode: string;
    externalReferenceId?: string;
    optInSupportAtHomeRates?: 'Y' | 'N' | '';
    centrelinkCrn?: string;
    dvaUin?: string;
    careLevel?: string;
    carerStatus?: string;
    awardOrSettlementTypeCode?: string;
    unfundedPriorEntryDate?: string;
    approvalSighted?: 'Y' | 'N' | '';
    address?: {
        streetLine?: string;
        suburb?: string;
        state?: string;
        postcode?: string;
    };
}
export interface CreateEntryRequestBody {
    businessId?: string;
    serviceNapsId: string;
    careRecipientId: string;
    entryDate: string;
    entryCategoryCode: string;
    externalReferenceId?: string;
    optInSupportAtHomeRates?: 'Y' | 'N' | '';
    centrelinkCrn?: string;
    dvaUin?: string;
    careLevel?: string;
    carerStatus?: string;
    awardOrSettlementTypeCode?: string;
    unfundedPriorEntryDate?: string;
    approvalSighted?: 'Y' | 'N' | '';
    address?: {
        streetLine?: string;
        suburb?: string;
        state?: string;
        postcode?: string;
    };
}
export interface CreateEntryResponse {
    eventId: string;
    status: string;
    channel: string;
    careRecipientName: string;
    serviceNapsId: string;
    serviceProviderId: string;
    careRecipientId: string;
    entryDate: string;
    entryCategoryCode: string;
    entryCategoryText: string;
    externalReferenceId: string;
    departureDate: string;
    departureReasonCode: string;
    departureEventId: string;
    optInSupportAtHomeRates: string;
    centrelinkCrn: string;
    dvaUin: string;
    careLevel: string;
    carerStatus: string;
    awardOrSettlementTypeCode: string;
    unfundedPriorEntryDate: string;
    approvalSighted: string;
    awardOrSettlementTypeText: string;
    departureReasonText: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    address?: {
        streetLine?: string;
        suburb?: string;
        state?: string;
        postcode?: string;
    };
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
}
export interface DeleteEntryQuery {
    businessId?: string;
}
export declare type GetDeparturesQuery = PaginatedQuery & {
    businessId?: string;
    serviceNapsId?: string;
    serviceProviderId?: string;
    careRecipientId?: string;
    externalReferenceId?: string;
    departureDateFrom?: string;
    departureDateTo?: string;
    updatedAtDateTimeFrom?: string;
    updatedAtDateTimeTo?: string;
    'sort-fields'?: 'createdAtDateTime' | 'updatedAtDateTime' | 'entryDate' | 'careRecipientId' | 'externalReferenceId';
};
export interface GetDeparturesItem {
    eventId: string;
    status: string;
    channel: string;
    serviceNapsId: string;
    serviceProviderId: string;
    careRecipientId: string;
    careRecipientName: string;
    externalReferenceId: string;
    entryCategoryCode: string;
    entryCategoryText: string;
    departureDate: string;
    departureReasonCode: string;
    departureReasonText: string;
    entryId: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
}
export declare type GetDeparturesResponse = PaginatedResponse<GetDeparturesItem>;
export interface GetDepartureQuery {
    businessId?: string;
}
export interface GetDepartureResponse {
    eventId: string;
    status: string;
    channel: string;
    serviceNapsId: string;
    serviceProviderId: string;
    careRecipientId: string;
    careRecipientName: string;
    externalReferenceId: string;
    entryCategoryCode: string;
    entryCategoryText: string;
    departureDate: string;
    departureReasonCode: string;
    departureReasonText: string;
    entryId: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
}
export interface UpdateDepartureRequestBody {
    businessId?: string;
    serviceNapsId: string;
    careRecipientId: string;
    externalReferenceId?: string;
    entryCategoryCode: string;
    departureDate: string;
    departureReasonCode: string;
}
export interface CreateDepartureRequestBody {
    businessId?: string;
    serviceNapsId: string;
    careRecipientId: string;
    externalReferenceId?: string;
    entryCategoryCode: string;
    departureDate: string;
    departureReasonCode: string;
}
export interface CreateDepartureResponse {
    eventId: string;
    status: string;
    channel: string;
    serviceNapsId: string;
    serviceProviderId: string;
    careRecipientId: string;
    careRecipientName: string;
    externalReferenceId: string;
    entryCategoryCode: string;
    entryCategoryText: string;
    departureDate: string;
    departureReasonCode: string;
    departureReasonText: string;
    entryId: string;
    createdAtDateTime: string;
    updatedAtDateTime: string;
    messages: Array<{
        type: string;
        shortText: string;
        longText: string;
    }>;
}
export interface DeleteDepartureQuery {
    businessId?: string;
}
export interface CreateEnteralFeedingSupplementAttachmentDownloadRequestBody {
    businessId?: string;
}
export interface CreateEnteralFeedingSupplementAttachmentDownloadRequestResponse {
    userDownloadId: string;
}
export interface CreateOxygenSupplementAttachmentDownloadRequestBody {
    businessId?: string;
}
export interface CreateOxygenSupplementAttachmentDownloadRequestResponse {
    userDownloadId: string;
}
