export interface Business {
    contactInfo: BusinessContactInformation;
    mfa: BusinessMFA;
    settings: BusinessSettings;
    settlement: {
        bankAccount: BusinessBankAccount;
    };
    funderIds: string[];
    currencyCode: string;
    billingNotificationEmails: string[];
    kycVerificationRequired: boolean;
    amountDailyRunningCardSalesTotal: number;
    status: string;
    isSignedUp: boolean;
    isV3Enabled: boolean;
    isFuturesEnabled: boolean;
    isSettlementReportEnabled: boolean;
    isSmsPaymentRequestsEnabled: boolean;
    isPracticesConfirmed: boolean;
    isStaffConfirmed: boolean;
    isServicesConfirmed: boolean;
    isBridgeEnabled: boolean;
    isDetailedRemittanceEnabled: boolean;
    isRejectedClaimNotificationEnabled: boolean;
    isMedicareEnabled: boolean;
    isIcareEnabled: boolean;
    isNdisEnabled: boolean;
    isWcqEnabled: boolean;
    isComcareEnabled: boolean;
    isWsvEnabled: boolean;
    isNibEnabled: boolean;
    isAssistedCardPaymentEnabled: boolean;
    isInvoiceUploadEnabled: boolean;
    isMedicareInvoiceUploadEnabled: boolean;
    isNewHicapsSeEnabled: boolean;
    isTyroTerminalEnabled: boolean;
    isEclipseEnabled: boolean;
    _id: string;
    abrOtherNames: string[];
    fullName: string;
    displayName: string;
    organisationId: string;
    modified: string;
    created: string;
    supportNotes: string[];
    refId: string;
    refSource: string;
    comcareEnabledDate: string;
    icareEnabledDate: string;
    nibEnabledDate: string;
    wcqEnabledDate: string;
    wsvEnabledDate: string;
    abn: string;
    ndisEnabledDate: string;
    address: string;
    addressPrefix: string;
    addressLine2?: string;
    city: string;
    country: string;
    countryCode: string;
    lnglat: [number, number];
    postcode: string;
    route: string;
    state: string;
    streetNumber: string;
    subpremise: string | null;
    abrOtherTradingNames: string[];
    medicareEnabledDate: string;
    _links: BusinessLinks;
}
export declare type ShortBusinessResponse = {
    abn: string;
    address: string;
    addressPrefix: string;
    addressLine2?: string;
    city: string;
    contactInfo: BusinessContactInformation;
    country: string;
    countryCode: string;
    displayName: string;
    fullName: string;
    gmapsPlaceId: string;
    lnglat: [number, number];
    postcode: string;
    route: string;
    state: string;
    streetNumber: string;
    subpremise: string | null;
    _id: string;
};
export declare type BusinessContactInformation = {
    landline: string;
    email: string;
    firstName: string;
    lastName: string;
    mobile: string;
};
declare type BusinessSettings = {
    transactions: {
        limits: {
            amountCardSalesPerTransaction: number;
            amountCardSalesPerDay: number;
            amountCardSalesPerTransactionString: string;
            amountCardSalesPerDayString: string;
        };
        smsPaymentRequestsEnabled: boolean;
        checkoutPayInPersonEnabled: boolean;
        alwaysSavePatientPaymentMethod: boolean;
    };
    medicare: {
        autoAcceptNonFatalClaim: boolean;
    };
    settlement: {
        settlementLevel: 'business' | 'practice';
        paymentFacility: 'medipass-payments' | null;
    };
};
declare type BusinessBankAccount = {
    accountName: string;
    accountNumber: string;
    bankName: string;
    bsb: string;
};
declare type BusinessLinks = {
    self: Links;
    practices: Links;
    services: Links;
    staff: Links;
    tranasctions: Links;
    documents: Links;
    subscriptions: Links;
    paymentMethods: Links;
};
declare type Links = {
    read?: string;
    update?: string;
    delete?: string;
};
declare type BusinessMFA = {
    strategy: string;
    expiresIn: number;
    expiresInType: string;
};
export {};
