import type { PaginationMeta, PaginatedQuery, HealthPointSettlementAttributes } from './index';
/** START: Query */
export declare type BusinessDocumentsQuery = PaginatedQuery & {
    isPublished?: boolean;
    practiceId?: string;
    sort?: string;
    documentType?: 'form' | 'application';
};
export declare type HealthFundDocumentsQuery = PaginatedQuery & {
    excludeDocumentIds?: string;
};
/** END: Query */
/** START: Requests */
export declare type DeclineHealthFundDocumentBody = {
    formApplicationDeclineReasonId: string;
    note?: string;
};
export declare type CeaseHealthFundDocumentBody = {
    formApplicationCeaseReasonId: string;
    note?: string;
};
export declare type ParkHealthFundDocumentBody = {
    workflowExceptionId: string;
    note?: string;
};
/** END: Requests */
/** START: Responses */
export declare type BusinessDocumentResponse = {
    _id: string;
    organisationId: string;
    healthFund: {
        _id: string;
        displayName: string;
    };
    documentType: string;
    documentId: string;
    fullName: string;
    displayName: string;
    description: string;
    visibilityRules: {
        businessRules: {
            modalityIds: Array<string>;
            states: Array<string>;
        };
    };
    status: string;
    isPublished?: boolean;
    created: string;
    modified: string;
};
export declare type BusinessDocumentsResponse = {
    meta: PaginationMeta;
    items: Array<BusinessDocumentResponse>;
};
export declare type HealthFundDocumentResponse = {
    _id: string;
    businessId: string;
    organisationId: string;
    healthFund: {
        _id: string;
        displayName: string;
    };
    funderId: string;
    createdByStaffName: string;
    documentNumber: string;
    documentType: string;
    documentId: string;
    fullName: string;
    displayName: string;
    description: string;
    visibilityRules: {
        businessRules: {
            modalityIds: Array<string>;
            states: Array<string>;
        };
    };
    practice: {
        _id: string;
        displayName: string;
        abn?: string;
        address?: string;
        city?: string;
        state?: string;
        country?: string;
    };
    workflowState: string;
    assignedToAccountId?: string;
    assignedToUsername?: string;
    approvedByAccountId?: string;
    approvedByUsername?: string;
    approvedDate?: string;
    createdByAccountId: string;
    createdByAccountUsername: string;
    declinedDate?: string;
    status: string;
    tags: Array<{
        _id: string;
        workflowException: {
            _id: string;
            code: string;
            displayName: string;
            description: string;
        };
        assignedByAccountId: string;
        assignedByUsername: string;
        notes?: string;
    }>;
    isPublished?: boolean;
    created: string;
    modified: string;
    _links: {
        self: {
            assign?: string;
            approve?: string;
            archive?: string;
            cease?: string;
            close?: string;
            decline?: string;
            park?: string;
            read?: string;
            unarchive?: string;
        };
    };
};
export declare type HealthFundDocumentsResponse = {
    meta: PaginationMeta;
    items: Array<HealthFundDocumentResponse>;
};
/** END: Responses */
/** START: Responses */
interface HealthPointResponse {
    deviceIds: [];
    digitalId: string;
    orgId: string;
    providerNumbers: [];
    siteId: string;
}
interface HealthPointRegisteredOrganisationResponse {
    orgId: string;
    status: string;
}
interface HealthPointRegisteredSiteResponse {
    siteId: string;
    status: string;
}
interface HealthPointRegisteredDigitalDeviceResponse {
    deviceId: string;
    status: string;
}
interface HealthPointRegisteredPhysicalDeviceResponse {
    deviceId: string;
    status: string;
}
interface HealthPointRegisteredProvidersResponse {
    providerNumber: string;
    status: string;
}
export declare enum HealthPointApplicationStatus {
    APPROVED = "approved",
    SUBMITTED = "submitted",
    REJECTED = "rejected"
}
interface HealthPointProviderSetFilesAttributes {
    category: string;
    displayName: string;
    url: string;
}
export interface HealthPointRegistrationApplicationResponse {
    business: {
        abn: string;
        address: string;
        addressPrefix: string;
        addressLine2?: string;
        city: string;
        contactInfo: {
            landline: string;
            email: string;
            firstName: string;
            lastName: string;
            mobile: string;
        };
        country: string;
        countryCode: string;
        displayName: string;
        fullName: string;
        gmapsPlaceId: string;
        lnglat: [number, number];
        postcode: string;
        route: string;
        state: string;
        streetNumber: string;
        subpremise: string | null;
        deleted: string | null;
        _id: string;
    };
    created: string;
    devicesRequested?: number;
    errorMessage?: string;
    formId: string;
    funderId: string;
    healthFundId: string;
    healthpoint: HealthPointResponse;
    isMidChecked?: boolean;
    isMidCheckedForSettlement?: boolean;
    isMidEnabled?: boolean;
    modified: string;
    practice: {
        tz: string;
        _id: string;
        deleted: string | null;
        fullName: string;
        displayName: string;
        mobile: string;
        email: string;
        lnglat: [number, number];
        gmapsPlaceId: string;
        address: string;
        addressPrefix?: string;
        countryCode: string;
        country: string;
        state: string;
        city: string;
        postcode: string;
        subpremise: string | null;
        streetNumber: string;
        route: string;
        mobileE164: string;
    };
    registeredDigitalDevice: HealthPointRegisteredDigitalDeviceResponse;
    registeredPhysicalDevices: HealthPointRegisteredPhysicalDeviceResponse[];
    registeredProviders: HealthPointRegisteredProvidersResponse[];
    registeredOrganisation: HealthPointRegisteredOrganisationResponse;
    registeredSite: HealthPointRegisteredSiteResponse;
    staffs: {
        firstName: string;
        lastName: string;
        _id: string;
        deleted: string | null;
        providerSet: {
            _id: string;
            deleted: string | null;
            professionalCategoryId: string;
            providerNumber: string;
            specialtyIds: string[];
            files?: HealthPointProviderSetFilesAttributes[];
            isCertificationMatch?: boolean;
            rejectionReason?: string;
            settlement?: HealthPointSettlementAttributes;
        }[];
    }[];
    status: HealthPointApplicationStatus;
    _id: string;
}
/** END: Responses */
/** START: Requests */
export interface UpdateHealthPointRegistrationApplicationBody {
    isMidChecked: boolean;
    isMidEnabled: boolean;
    isMidCheckedForSettlement?: boolean;
    staffs: {
        _id: string;
        providerSet: {
            _id: string;
            isCertificationMatch?: boolean;
            rejectionReason?: string;
        }[];
    }[];
}
export interface ActivateHealthPointDigitalClaimingBody {
    numberOfDevices: number;
}
export {};
/** END: Requests */
